class EosCompaction:
    """The EosCompaction object specifies material eos compaction.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].eos.eosCompaction
            import odbMaterial
            session.odbs[name].materials[name].eos.eosCompaction

        The corresponding analysis keywords are:

        - EOS COMPACTION
    """

    def __init__(
        self,
        soundSpeed: float,
        porosity: float,
        pressure: float,
        compactionPressure: float,
    ):
        """This method creates an EosCompaction object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].eos.EosCompaction
                session.odbs[name].materials[name].eos.EosCompaction

        Parameters
        ----------
        soundSpeed
            A Float specifying reference sound speed in the porous material.
        porosity
            A Float specifying value of the porosity of the unloaded material.
        pressure
            A Float specifying pressure required to initialize Plastic behavior.
        compactionPressure
            A Float specifying compaction pressure at which all pores are crushed.

        Returns
        -------
        EosCompaction
            An :py:class:`~abaqus.Material.Eos.EosCompaction.EosCompaction` object.

        Raises
        ------
        RangeError
        """
        pass

    def setValues(self, *args, **kwargs):
        """This method modifies the EosCompaction object.

        Raises
        ------
        RangeError
        """
        pass



class SaturationDependence:
    r"""The SaturationDependence object specifies the dependence of the permeability of a
    material on the saturation of the wetting liquid.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].permeability.saturationDependence
            import odbMaterial
            session.odbs[name].materials[name].permeability.saturationDependence

        The table data for this object are:

        - :math:`k_{s}`. (Dimensionless.)
        - Saturation, :math:`\boldsymbol{S}`. (Dimensionless.)

        The corresponding analysis keywords are:

        - PERMEABILITY
    """

    def __init__(self, table: tuple):
        """This method creates a SaturationDependence object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].permeability.SaturationDependence
                session.odbs[name].materials[name].permeability.SaturationDependence

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.

        Returns
        -------
        SaturationDependence
            A :py:class:`~abaqus.Material.Others.PoreFluidFlow.Permeability.SaturationDependence.SaturationDependence` object.

        Raises
        ------
        RangeError
        """
        pass

    def setValues(self, *args, **kwargs):
        """This method modifies the SaturationDependence object.

        Raises
        ------
        RangeError
        """
        pass



from abaqusConstants import *


class ConcreteCompressionDamage:
    r"""The ConcreteCompressionDamage object specifies hardening for the concrete damaged
    plasticity model.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].concreteDamagedPlasticity.concreteCompressionDamage
            import odbMaterial
            session.odbs[name].materials[name].concreteDamagedPlasticity.concreteCompressionDamage

        The table data for this object are:

        - Compressive damage variable, :math:`d_{c}`.
        - Inelastic (crushing) strain, :math:`\epsilon_{c}^{i n}`.
        - Temperature, if the data depend on temperature.
        - Value of the first field variable, if the data depend on field variables.
        - Value of the second field variable.
        - Etc.

        The corresponding analysis keywords are:

        - CONCRETE COMPRESSION DAMAGE
    """

    def __init__(
        self,
        table: tuple,
        tensionRecovery: float = 0,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
    ):
        """This method creates a ConcreteCompressionDamage object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].concreteDamagedPlasticity.ConcreteCompressionDamage
                session.odbs[name].materials[name].concreteDamagedPlasticity.ConcreteCompressionDamage

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.
        tensionRecovery
            A Float specifying the value of the stiffness recovery factor, :math:`w_{t}`, that determines the
            amount of tension stiffness that is recovered as loading changes from compression to
            tension. The default value is 0.0.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.

        Returns
        -------
        ConcreteCompressionDamage
            A :py:class:`~abaqus.Material.Plastic.Concrete.ConcreteCompressionDamage.ConcreteCompressionDamage` object.

        Raises
        ------
        RangeError
        """
        pass

    def setValues(self, *args, **kwargs):
        """This method modifies the ConcreteCompressionDamage object.

        Raises
        ------
        RangeError
        """
        pass



from abaqusConstants import *
from ..Region.Region import Region


class IntegratedOutputSection:
    """The IntegratedOutputSection object specifies parameters used for integrated output.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import step
            mdb.models[name].integratedOutputSections[name]
    """

    #: A String specifying the repository key.
    name: str

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the surface over which the output is based.
    surface: Region

    #: None or a Region object specifying the anchor point about which the integrated moment
    #: over the output region is computed or the SymbolicConstant None representing the global
    #: origin. The default value is None.
    refPoint: SymbolicConstant = None

    #: A Boolean specifying that the **refPoint** be adjusted so that it coincides with the
    #: center of the output region in the initial configuration. This argument is valid only
    #: when you include the **refPoint** argument. The default value is OFF.
    refPointAtCenter: Boolean = OFF

    #: A SymbolicConstant specifying how to relate the motion of **refPoint** to the average
    #: motion of the output region. A value of INDEPENDENT will allow the **refPoint** to move
    #: independent of the output region. A value of AVERAGE_TRANSLATION will set the
    #: displacement of the **refPoint** equal to the average translation of the output region. A
    #: value of AVERAGE will set the displacement and rotation of the **refPoint** equal to the
    #: average translation of the output region. The default value is INDEPENDENT.This argument
    #: is valid only when you include the **refPoint** argument.
    refPointMotion: SymbolicConstant = INDEPENDENT

    #: None or a DatumCsys object specifying the local coordinate system used to express vector
    #: output. If **localCsys** = None, the degrees of freedom are defined in the global coordinate
    #: system. The default value is None.
    localCsys: str = None

    #: A Boolean specifying that the coordinate system be projected onto the **surface** such
    #: that the 1-axis is normal to the **surface**. Projection onto a planar **surface** is such
    #: that the 1-axis is normal to the surface, and a projection onto a nonplanar **surface** is
    #: such that a least-squares fit surface will be used. The default value is OFF.
    projectOrientation: Boolean = OFF

    def __init__(
        self,
        name: str,
        surface: Region,
        refPoint: SymbolicConstant = None,
        refPointAtCenter: Boolean = OFF,
        refPointMotion: SymbolicConstant = INDEPENDENT,
        localCsys: str = None,
        projectOrientation: Boolean = OFF,
    ):
        """This method creates an IntegratedOutputSection object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].IntegratedOutputSection

        Parameters
        ----------
        name
            A String specifying the repository key.
        surface
            A :py:class:`~abaqus.Region.Region.Region` object specifying the surface over which the output is based.
        refPoint
            None or a Region object specifying the anchor point about which the integrated moment
            over the output region is computed or the SymbolicConstant None representing the global
            origin. The default value is None.
        refPointAtCenter
            A Boolean specifying that the **refPoint** be adjusted so that it coincides with the
            center of the output region in the initial configuration. This argument is valid only
            when you include the **refPoint** argument. The default value is OFF.
        refPointMotion
            A SymbolicConstant specifying how to relate the motion of **refPoint** to the average
            motion of the output region. A value of INDEPENDENT will allow the **refPoint** to move
            independent of the output region. A value of AVERAGE_TRANSLATION will set the
            displacement of the **refPoint** equal to the average translation of the output region. A
            value of AVERAGE will set the displacement and rotation of the **refPoint** equal to the
            average translation of the output region. The default value is INDEPENDENT.This argument
            is valid only when you include the **refPoint** argument.
        localCsys
            None or a DatumCsys object specifying the local coordinate system used to express vector
            output. If **localCsys** = None, the degrees of freedom are defined in the global coordinate
            system. The default value is None.
        projectOrientation
            A Boolean specifying that the coordinate system be projected onto the **surface** such
            that the 1-axis is normal to the **surface**. Projection onto a planar **surface** is such
            that the 1-axis is normal to the surface, and a projection onto a nonplanar **surface** is
            such that a least-squares fit surface will be used. The default value is OFF.

        Returns
        -------
        IntegratedOutputSection
            An :py:class:`~abaqus.StepOutput.IntegratedOutputSection.IntegratedOutputSection` object.
        """
        pass

    def setValues(
        self,
        surface: Region,
        refPoint: SymbolicConstant = None,
        refPointAtCenter: Boolean = OFF,
        refPointMotion: SymbolicConstant = INDEPENDENT,
        localCsys: str = None,
        projectOrientation: Boolean = OFF,
    ):
        """This method modifies the IntegratedOutputSection object.

        Parameters
        ----------
        surface
            A :py:class:`~abaqus.Region.Region.Region` object specifying the surface over which the output is based.
        refPoint
            None or a Region object specifying the anchor point about which the integrated moment
            over the output region is computed or the SymbolicConstant None representing the global
            origin. The default value is None.
        refPointAtCenter
            A Boolean specifying that the **refPoint** be adjusted so that it coincides with the
            center of the output region in the initial configuration. This argument is valid only
            when you include the **refPoint** argument. The default value is OFF.
        refPointMotion
            A SymbolicConstant specifying how to relate the motion of **refPoint** to the average
            motion of the output region. A value of INDEPENDENT will allow the **refPoint** to move
            independent of the output region. A value of AVERAGE_TRANSLATION will set the
            displacement of the **refPoint** equal to the average translation of the output region. A
            value of AVERAGE will set the displacement and rotation of the **refPoint** equal to the
            average translation of the output region. The default value is INDEPENDENT.This argument
            is valid only when you include the **refPoint** argument.
        localCsys
            None or a DatumCsys object specifying the local coordinate system used to express vector
            output. If **localCsys** = None, the degrees of freedom are defined in the global coordinate
            system. The default value is None.
        projectOrientation
            A Boolean specifying that the coordinate system be projected onto the **surface** such
            that the 1-axis is normal to the **surface**. Projection onto a planar **surface** is such
            that the 1-axis is normal to the surface, and a projection onto a nonplanar **surface** is
            such that a least-squares fit surface will be used. The default value is OFF.
        """
        pass



from abaqusConstants import *


class DiagnosticPrint:
    """The DiagnosticPrint object is used to request detailed diagnostic output or to disable
    specific diagnostic checks

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import step
            mdb.models[name].steps[name].diagnosticPrint

        The corresponding analysis keywords are:

        - DIAGNOSTICS
    """

    #: A Boolean specifying a request for a column containing the total kinetic energy. This
    #: argument is valid only for an Abaqus/Explicit analysis. The default value is ON.
    allke: Boolean = ON

    #: A Boolean specifying a request for a column containing the element that has the smallest
    #: stable time increment and a column listing the value. This argument is valid only for an
    #: Abaqus/Explicit analysis. The default value is ON.
    criticalElement: Boolean = ON

    #: A Boolean specifying a request for a column containing the percent change in total mass
    #: of the model as a result of mass scaling. This argument is valid only for an
    #: Abaqus/Explicit analysis. The default value is OFF unless mass scaling is present in the
    #: model.
    dmass: Boolean = OFF

    #: A Boolean specifying a request for a column containing the energy balance of the model.
    #: This argument is valid only for an Abaqus/Explicit analysis. The default value is OFF.
    etotal: Boolean = OFF

    #: A Boolean specifying a request for detailed output of points that are contacting or
    #: separating in interface and gap problems. This argument is valid only for an
    #: Abaqus/Standard analysis. The default value is ON.
    contact: Boolean = ON

    #: A Boolean specifying a request for detailed output of which elements are being removed
    #: or reactivated in the step. This argument is valid only for an Abaqus/Standard analysis.
    #: The default value is OFF.
    modelChange: Boolean = OFF

    #: A Boolean specifying a request for detailed output of element and integration point
    #: numbers for which the plasticity algorithms have failed to converge in the material
    #: routines. This argument is valid only for an Abaqus/Standard analysis. The default value
    #: is OFF.
    plasticity: Boolean = OFF

    #: A Boolean specifying a request for output of equilibrium residuals during the
    #: equilibrium iterations. This argument is valid only for an Abaqus/Standard analysis. The
    #: default value is ON.
    residual: Boolean = ON

    #: An Int specifying the frequency of output, in increments. The default value is 1.
    frequency: int = 1

    #: A Boolean specifying a request for information regarding the actual number of equations
    #: and the wavefront in each iteration. This argument is valid only for an Abaqus/Standard
    #: analysis. The default value is ON.
    

    #: A Boolean specifying a request for a column containing the total mass of the model as a
    #: result of mass scaling. This argument is valid only for an Abaqus/Explicit analysis. The
    #: default value is OFF.
    mass: Boolean = OFF

    def __init__(
        self,
        allke: Boolean = ON,
        criticalElement: Boolean = ON,
        dmass: Boolean = OFF,
        etotal: Boolean = OFF,
        contact: Boolean = ON,
        modelChange: Boolean = OFF,
        plasticity: Boolean = OFF,
        residual: Boolean = ON,
        frequency: int = 1,
        solve: Boolean = ON,
        mass: Boolean = OFF,
    ):
        """This method creates a DiagnosticPrint object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].steps[name].DiagnosticPrint

        Parameters
        ----------
        allke
            A Boolean specifying a request for a column containing the total kinetic energy. This
            argument is valid only for an Abaqus/Explicit analysis. The default value is ON.
        criticalElement
            A Boolean specifying a request for a column containing the element that has the smallest
            stable time increment and a column listing the value. This argument is valid only for an
            Abaqus/Explicit analysis. The default value is ON.
        dmass
            A Boolean specifying a request for a column containing the percent change in total mass
            of the model as a result of mass scaling. This argument is valid only for an
            Abaqus/Explicit analysis. The default value is OFF unless mass scaling is present in the
            model.
        etotal
            A Boolean specifying a request for a column containing the energy balance of the model.
            This argument is valid only for an Abaqus/Explicit analysis. The default value is OFF.
        contact
            A Boolean specifying a request for detailed output of points that are contacting or
            separating in interface and gap problems. This argument is valid only for an
            Abaqus/Standard analysis. The default value is ON.
        modelChange
            A Boolean specifying a request for detailed output of which elements are being removed
            or reactivated in the step. This argument is valid only for an Abaqus/Standard analysis.
            The default value is OFF.
        plasticity
            A Boolean specifying a request for detailed output of element and integration point
            numbers for which the plasticity algorithms have failed to converge in the material
            routines. This argument is valid only for an Abaqus/Standard analysis. The default value
            is OFF.
        residual
            A Boolean specifying a request for output of equilibrium residuals during the
            equilibrium iterations. This argument is valid only for an Abaqus/Standard analysis. The
            default value is ON.
        frequency
            An Int specifying the frequency of output, in increments. The default value is 1.
        solve
            A Boolean specifying a request for information regarding the actual number of equations
            and the wavefront in each iteration. This argument is valid only for an Abaqus/Standard
            analysis. The default value is ON.
        mass
            A Boolean specifying a request for a column containing the total mass of the model as a
            result of mass scaling. This argument is valid only for an Abaqus/Explicit analysis. The
            default value is OFF.

        Returns
        -------
        DiagnosticPrint
            A :py:class:`~abaqus.StepOutput.DiagnosticPrint.DiagnosticPrint` object.
        """
        pass

    def setValues(self, *args, **kwargs):
        """This method modifies the DiagnosticPrint object."""
        pass



from abaqusConstants import *
from .OdbMeshNode import OdbMeshNode
from .OdbSet import OdbSet


class BeamOrientation:
    """The BeamOrientation object represents the direction of the first beam section axis n1n1.
    Specifying the beam orientation using an additional node in the element connectivity
    list is not supported.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import odbAccess
            session.odbs[name].parts[name].beamOrientations[i]
            session.odbs[name].rootAssembly.instances[name].beamOrientations[i]
            session.odbs[name].steps[name].frames[i].fieldOutputs[name].values[i].instance.beamOrientations[i]
    """

    #: A SymbolicConstant specifying the orientation assignment method. Possible values are
    #: N1_COSINES, CSYS, and VECT.
    method: SymbolicConstant = None

    #: An :py:class:`~abaqus.Odb.OdbSet.OdbSet` object specifying a region for which the beam orientation is defined.
    region: OdbSet = OdbSet("set", tuple[OdbMeshNode]())

    #: A tuple of Floats specifying direction cosines of the n1-direction of the beam
    #: cross-section.
    vector: float = None



from .CompositeDampingComponentArray import CompositeDampingComponentArray


class CompositeDamping:
    """A :py:class:`~abaqus.StepMiscellaneous.CompositeDamping.CompositeDamping` object contains composite modal damping parameters.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import step
            mdb.models[name].steps[name].compositeDamping
    """

    #: A :py:class:`~abaqus.StepMiscellaneous.CompositeDampingComponentArray.CompositeDampingComponentArray` object.
    components: CompositeDampingComponentArray = CompositeDampingComponentArray()



from abaqusConstants import *


class Light:
    """The Light object stores settings that control how objects are lit when the **renderStyle**
    is set to SHADED.
    The Light object has no constructor; Abaqus creates them as part of the
    **defaultLightOptions** and the **lightOptions** objects when a session is started.

    Notes
    -----
    This object can be accessed by:

    .. code-block::

        session.defaultLightOptions.lights[i]
        session.viewports[name].lightOptions.lights[i]
    """

    def setValues(
        self,
        enabled: Boolean = OFF,
        type: SymbolicConstant = DIRECTIONAL,
        latitude: float = 0,
        longitude: float = 0,
        diffuseColor: str = "",
        specularColor: str = "",
    ):
        """This method modifies the Light object.

        Parameters
        ----------
        enabled
            A Boolean specifying whether the light is on or off. The default value is OFF.
        type
            A SymbolicConstant specifying how the effect of the light should be calculated. Possible
            values are:DIRECTIONAL, specifying a constant vector should be used for the direction
            from the light to a vertex.POINT, specifying the vector from the light to each vertex
            should be calculated.The default value is DIRECTIONAL.When set to **type** =DIRECTIONAL, a
            constant vector is used for the direction from the light to a vertex. When **type**
            =POINT, the result is more realistic because the actual vector from the light to each
            vertex is calculated. However, overall performance is decreased.
        latitude
            A Float specifying the altitude of the light above or below the camera. Possible values
            are -90.0 ≤≤ **latitude** ≤≤ 90.0. The default value is 0.0.
        longitude
            A Float specifying the east/west position of the light to the left or right of the
            camera. Possible values are -90.0 ≤≤ **longitude** ≤≤ 90.0. The default value is 0.0.
        diffuseColor
            A String specifying the color of the light added to the scene by this light source. The
            initial value is 70% gray. A list of valid color strings is in the **colors** map in the
            **session** object.
        specularColor
            A String specifying the color of the specular highlights created by this light source.
            The initial value is 36% gray. A list of valid color strings is in the **colors** map in
            the **session** object.

        Raises
        ------
        RangeError
        """
        pass



from .ConstrainedSketchConstraint import ConstrainedSketchConstraint
from ..ConstrainedSketchGeometry.ConstrainedSketchGeometry import (
    ConstrainedSketchGeometry,
)


class CoincidentConstraint(ConstrainedSketchConstraint):
    def __init__(
        self, entity1: ConstrainedSketchGeometry, entity2: ConstrainedSketchGeometry
    ):
        """This method creates a coincident constraint. This constraint applies to two vertices, to
        a vertex and a ConstrainedSketchGeometry object, or to two ConstrainedSketchGeometry
        objects of the same type and constrains them to be coincident.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].sketches[name].CoincidentConstraint

        Parameters
        ----------
        entity1
            A :py:class:`~abaqus.Sketcher.ConstrainedSketchGeometry.ConstrainedSketchGeometry.ConstrainedSketchGeometry` object or a ConstrainedSketchVertex object specifying the first object.
        entity2
            A :py:class:`~abaqus.Sketcher.ConstrainedSketchGeometry.ConstrainedSketchGeometry.ConstrainedSketchGeometry` object or a ConstrainedSketchVertex object specifying the second object.

        Returns
        -------
        ConstrainedSketchConstraint
            A :py:class:`~abaqus.Sketcher.ConstrainedSketchConstraint.ConstrainedSketchConstraint.ConstrainedSketchConstraint` object.

        """
        pass



from abaqusConstants import *


class Piezoelectric:
    r"""The Piezoelectric object specifies piezoelectric material properties.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].piezoelectric
            import odbMaterial
            session.odbs[name].materials[name].piezoelectric

        The table data for this object are:

        - If **type** = STRESS, the table data specify the following:
        
            - :math:`e_{111}^{\varphi}`.
            - :math:`e_{122}^{\varphi}`.
            - :math:`e_{133}^{\varphi}`.
            - :math:`e_{112}^{\varphi}`.
            - :math:`e_{113}^{\varphi}`.
            - :math:`e_{123}^{\varphi}`.
            - :math:`e_{211}^{\varphi}`.
            - :math:`e_{222}^{\varphi}`.
            - :math:`e_{233}^{\varphi}`.
            - :math:`e_{212}^{\varphi}`.
            - :math:`e_{213}^{\varphi}`.
            - :math:`e_{223}^{\varphi}`.
            - :math:`e_{311}^{\varphi}`.
            - :math:`e_{322}^{\varphi}`.
            - :math:`e_{333}^{\varphi}`.
            - :math:`e_{312}^{\varphi}`.
            - :math:`e_{313}^{\varphi}`.
            - :math:`e_{323}^{\varphi}`.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **type** = STRAIN, the table data specify the following:
        
            - :math:`d_{111}^{\varphi}`.
            - :math:`d_{122}^{\varphi}`.
            - :math:`d_{133}^{\varphi}`.
            - :math:`d_{112}^{\varphi}`.
            - :math:`d_{113}^{\varphi}`.
            - :math:`d_{123}^{\varphi}`.
            - :math:`d_{211}^{\varphi}`.
            - :math:`d_{222}^{\varphi}`.
            - :math:`d_{233}^{\varphi}`.
            - :math:`d_{212}^{\varphi}`.
            - :math:`d_{213}^{\varphi}`.
            - :math:`d_{223}^{\varphi}`.
            - :math:`d_{311}^{\varphi}`.
            - :math:`d_{322}^{\varphi}`.
            - :math:`d_{333}^{\varphi}`.
            - :math:`d_{313}^{\varphi}`.
            - :math:`d_{323}^{\varphi}`.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.

        The corresponding analysis keywords are:

        - PIEZOELECTRIC
    """

    def __init__(
        self,
        table: tuple,
        type: SymbolicConstant = STRESS,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
    ):
        """This method creates a Piezoelectric object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].Piezoelectric
                session.odbs[name].materials[name].Piezoelectric

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.
        type
            A SymbolicConstant specifying the type of material coefficients for the piezoelectric
            property. Possible values are STRAIN and STRESS. The default value is STRESS.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.

        Returns
        -------
        Piezoelectric
            A :py:class:`~abaqus.Material.Others.Electromagnetic.Piezoelectric.Piezoelectric` object.
        """
        pass

    def setValues(self, *args, **kwargs):
        """This method modifies the Piezoelectric object."""
        pass



from abaqusConstants import *
from .Load import Load
from ..Datum.DatumAxis import DatumAxis
from ..Region.Region import Region


class BoltLoad(Load):
    """The BoltLoad object defines a bolt load.
    The BoltLoad object is derived from the Load object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].loads[name]

        The corresponding analysis keywords are:

        - PRE-TENSION SECTION
                - NODE
                - NSET
    """

    #: A String specifying the load repository key.
    name: str = ""

    #: A :py:class:`~abaqus.Datum.DatumAxis.DatumAxis` object specifying the orientation of the pre-tension section
    #: normal.Note:*datumAxis* is required only for Solid and Shell regions; it has no meaning
    #: for Wire regions.
    datumAxis: DatumAxis = DatumAxis()

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the load is applied.
    region: Region = Region()

    def __init__(
        self,
        name: str,
        createStepName: str,
        region: Region,
        magnitude: float,
        datumAxis: DatumAxis,
        boltMethod: SymbolicConstant = APPLY_FORCE,
        amplitude: str = UNSET,
        preTenSecPartLevel: Boolean = False,
    ):
        """This method creates a BoltLoad object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].BoltLoad

        Parameters
        ----------
        name
            A String specifying the load repository key.
        createStepName
            A String specifying the name of the step in which the load is created. This must be the
            first analysis step name.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the load is applied.
        magnitude
            A Float specifying the bolt load magnitude.
        datumAxis
            A :py:class:`~abaqus.Datum.DatumAxis.DatumAxis` object specifying the orientation of the pre-tension section normal.Note:
            **datumAxis** is applicable only for Solid and Shell regions; it has no meaning for Wire
            regions.
        boltMethod
            A SymbolicConstant specifying the method of applying the bolt load. Possible values are
            APPLY_FORCE and ADJUST_LENGTH. The default value is APPLY_FORCE.
        amplitude
            A String or the SymbolicConstant UNSET specifying the name of the amplitude reference.
            UNSET should be used if the load has no amplitude reference. The default value is UNSET.
            You should provide the **amplitude** argument only if it is valid for the specified step.
        preTenSecPartLevel
            A Boolean specifying whether the pre-tension section is to be defined at the part level.
            The default value is False. You should provide the **preTenSecPartLevel** argument only if
            the selected region belongs to a dependent part instance. A pre-tension section cannot
            be defined at the part level for independent and model instances.

        Returns
        -------
        BoltLoad
            A :py:class:`~abaqus.Load.BoltLoad.BoltLoad` object.

        Raises
        ------
        TextError
        """
        super().__init__()
        pass

    def setValues(
        self,
        boltMethod: SymbolicConstant = APPLY_FORCE,
        datumAxis: DatumAxis = None, 
        amplitude: str = UNSET,
        preTenSecPartLevel: Boolean = False,
    ):
        """This method modifies the data for an existing BoltLoad object in the step where it is
        created.

        Parameters
        ----------
        boltMethod
            A SymbolicConstant specifying the method of applying the bolt load. Possible values are
            APPLY_FORCE and ADJUST_LENGTH. The default value is APPLY_FORCE.
        datumAxis
            A :py:class:`~abaqus.Datum.DatumAxis.DatumAxis` object specifying the orientation of the pre-tension section normal.Note:
            **datumAxis** is applicable only for Solid and Shell regions; it has no meaning for Wire
            regions.
        amplitude
            A String or the SymbolicConstant UNSET specifying the name of the amplitude reference.
            UNSET should be used if the load has no amplitude reference. The default value is UNSET.
            You should provide the **amplitude** argument only if it is valid for the specified step.
        preTenSecPartLevel
            A Boolean specifying whether the pre-tension section is to be defined at the part level.
            The default value is False. You should provide the **preTenSecPartLevel** argument only if
            the selected region belongs to a dependent part instance. A pre-tension section cannot
            be defined at the part level for independent and model instances.
        """
        pass

    def setValuesInStep(
        self,
        stepName: str,
        boltMethod: SymbolicConstant = APPLY_FORCE,
        magnitude: float = None,
        amplitude: str = "",
    ):
        """This method modifies the propagating data for an existing BoltLoad object in the
        specified step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the load is modified.
        boltMethod
            A SymbolicConstant specifying the type of bolt load. Possible values are APPLY_FORCE,
            ADJUST_LENGTH, and FIX_LENGTH. The default is APPLY_FORCE.
        magnitude
            A Float specifying the bolt load magnitude.
        amplitude
            A String or a SymbolicConstant specifying the name of the amplitude reference. Possible
            values for the SymbolicConstant are UNCHANGED and FREED. UNCHANGED should be used if the
            amplitude is propagated from the previous analysis step. FREED should be used if the
            load is changed to have no amplitude reference. You should provide the **amplitude**
            argument only if it is valid for the specified step.
        """
        pass



"""The following command is used to record a user-defined command in the Abaqus journal
file. 

"""


def journalMethodCall(objectPath: str, methodName: str, args: tuple, kargs: str):
    """This function may be used by a user-defined command to record itself in the Abaqus
    journal file.
    For example
    def setValues( self, **kargs ):
            for arg,value in kargs.items():
                setattr(arg, value)
            from abaqus import journalMethodCall
            objPath = '%s[%r]' % (self.reposPath, self.name)
            journalMethodCall(objPath, 'setValues', (), kargs)
    Note:Your command should not call journalMethodCall if the command changes the mdb using
    built-in Abaqus Scripting Interface commands, because built-in commands are journaled by
    default. A command that changes the mdb customData is one example of a command that
    should call journalMethodCall.

    .. note:: 
        This function can be accessed by:

        .. code-block:: python

            journalMethodCall

    Parameters
    ----------
    objectPath
        A String specifying the path to the object.
    methodName
        A String specifying the name of the method.
    args
        A sequence specifying the positional arguments to be written to the journal file.
    kargs
        A Python dict object specifying the keyword arguments to be written to the journal file.
    """
    pass



import typing

from abaqusConstants import *
from .Load import Load
from ..Region.Region import Region


class Moment(Load):
    """The Moment object stores the data for a moment.
    The Moment object is derived from the Load object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].loads[name]
    """

    #: A String specifying the load repository key.
    name: str = ""

    #: A SymbolicConstant specifying how the load is distributed spatially. Possible values are
    #: UNIFORM and FIELD. The default value is UNIFORM.
    distributionType: SymbolicConstant = UNIFORM

    #: A Boolean specifying whether the direction of the force rotates with the rotation of the
    #: node. You should provide the **follower** argument only if it is valid for the specified
    #: step. The default value is OFF.
    follower: Boolean = OFF

    #: None or a DatumCsys object specifying the ID of the Datum coordinate system used as the
    #: local coordinate system of the load. If **localCsys** = None, the load is defined in the
    #: global coordinate system. When this member is queried, it returns an Int. The default
    #: value is None.
    localCsys: int = None

    #: A String specifying the name of the AnalyticalField object associated with this load.
    #: The **field** argument applies only when **distributionType** = FIELD. The default value is an
    #: empty string.
    field: str = ""

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the load is applied.
    region: Region = Region()

    def __init__(
        self,
        name: str,
        createStepName: str,
        region: Region,
        cm1: float = None,
        cm2: float = None,
        cm3: float = None,
        amplitude: str = UNSET,
        follower: Boolean = OFF,
        localCsys: int = None,
        distributionType: SymbolicConstant = UNIFORM,
        field: str = "",
    ):
        """This method creates a Moment object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].Moment

        Parameters
        ----------
        name
            A String specifying the load repository key.
        createStepName
            A String specifying the name of the step in which the load is created.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the load is applied.
        cm1
            A Float or a Complex specifying the load component in the 4-direction.Note:Although
            **comp1**, **comp2**, and **comp3** are optional arguments, at least one of them must be
            nonzero.
        cm2
            A Float or a Complex specifying the load component in the 5- direction.
        cm3
            A Float or a Complex specifying the load component in the 6-direction.
        amplitude
            A String or the SymbolicConstant UNSET specifying the name of the amplitude reference.
            UNSET should be used if the load has no amplitude reference. The default value is UNSET.
            You should provide the **amplitude** argument only if it is valid for the specified step.
        follower
            A Boolean specifying whether the direction of the force rotates with the rotation of the
            node. You should provide the **follower** argument only if it is valid for the specified
            step. The default value is OFF.
        localCsys
            None or a DatumCsys object specifying the ID of the Datum coordinate system used as the
            local coordinate system of the load. If **localCsys** = None, the load is defined in the
            global coordinate system. When this member is queried, it returns an Int. The default
            value is None.
        distributionType
            A SymbolicConstant specifying how the load is distributed spatially. Possible values are
            UNIFORM and FIELD. The default value is UNIFORM.
        field
            A String specifying the name of the AnalyticalField object associated with this load.
            The **field** argument applies only when **distributionType** = FIELD. The default value is an
            empty string.

        Returns
        -------
        Moment
            A :py:class:`~abaqus.Load.Moment.Moment` object.
        """
        super().__init__()
        pass

    def setValues(
        self,
        cm1: float = None,
        cm2: float = None,
        cm3: float = None,
        amplitude: str = UNSET,
        follower: Boolean = OFF,
        localCsys: int = None,
        distributionType: SymbolicConstant = UNIFORM,
        field: str = "",
    ):
        """This method modifies the data for an existing Moment object in the step where it is
        created.

        Parameters
        ----------
        cm1
            A Float or a Complex specifying the load component in the 4-direction.Note:Although
            **comp1**, **comp2**, and **comp3** are optional arguments, at least one of them must be
            nonzero.
        cm2
            A Float or a Complex specifying the load component in the 5- direction.
        cm3
            A Float or a Complex specifying the load component in the 6-direction.
        amplitude
            A String or the SymbolicConstant UNSET specifying the name of the amplitude reference.
            UNSET should be used if the load has no amplitude reference. The default value is UNSET.
            You should provide the **amplitude** argument only if it is valid for the specified step.
        follower
            A Boolean specifying whether the direction of the force rotates with the rotation of the
            node. You should provide the **follower** argument only if it is valid for the specified
            step. The default value is OFF.
        localCsys
            None or a DatumCsys object specifying the ID of the Datum coordinate system used as the
            local coordinate system of the load. If **localCsys** = None, the load is defined in the
            global coordinate system. When this member is queried, it returns an Int. The default
            value is None.
        distributionType
            A SymbolicConstant specifying how the load is distributed spatially. Possible values are
            UNIFORM and FIELD. The default value is UNIFORM.
        field
            A String specifying the name of the AnalyticalField object associated with this load.
            The **field** argument applies only when **distributionType** = FIELD. The default value is an
            empty string.
        """
        pass

    def setValuesInStep(
        self,
        stepName: str,
        comp1: typing.Union[SymbolicConstant, float] = None,
        comp2: typing.Union[SymbolicConstant, float] = None,
        comp3: typing.Union[SymbolicConstant, float] = None,
        amplitude: str = "",
    ):
        """This method modifies the propagating data for an existing Moment object in the specified
        step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the load is modified.
        comp1
            A Float, a Complex, or a SymbolicConstant specifying the load component in the
            4-direction. Possible values for the SymbolicConstant are UNCHANGED and FREED. UNCHANGED
            should be used if the load component is propagated from the previous static analysis
            step. Use FREED to remove a previously defined load component.
        comp2
            A Float, a Complex, or a SymbolicConstant specifying the load component in the
            5-direction. For details see **comp1**.
        comp3
            A Float, a Complex, or a SymbolicConstant specifying the load component in the
            6-direction. For details see **comp1**.
        amplitude
            A String or a SymbolicConstant specifying the name of the amplitude reference. Possible
            values for the SymbolicConstant are UNCHANGED and FREED. UNCHANGED should be used if the
            amplitude is propagated from the previous static analysis step. FREED should be used if
            the load is changed to have no amplitude reference. You should provide the **amplitude**
            argument only if it is valid for the specified step.
        """
        pass



from abaqusConstants import *
from .GeometricRestriction import GeometricRestriction
from ..Region.Region import Region


class BeadFixedRegion(GeometricRestriction):
    """The BeadFixedRegion object defines a fixed region geometric restriction.
    The BeadFixedRegion object is derived from the GeometricRestriction object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import optimization
            mdb.models[name].optimizationTasks[name].geometricRestrictions[name]
    """

    #: A String specifying the geometric restriction repository key.
    name: str

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the geometric restriction is applied.
    region: Region

    #: None or a DatumCsys object specifying the local coordinate system. If **csys** = None, the
    #: global coordinate system is used. When this member is queried, it returns an Int. The
    #: default value is None.
    csys: int = None

    #: A Boolean specifying whether to fix the region in the 1-direction. The default value is
    #: OFF.
    u1: Boolean = OFF

    #: A Boolean specifying whether to fix the region in the 2-direction. The default value is
    #: OFF.
    u2: Boolean = OFF

    #: A Boolean specifying whether to fix the region in the 3-direction. The default value is
    #: OFF.
    u3: Boolean = OFF

    def __init__(
        self,
        name: str,
        region: Region,
        csys: int = None,
        u1: Boolean = OFF,
        u2: Boolean = OFF,
        u3: Boolean = OFF,
    ):
        """This method creates a BeadFixedRegion object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].optimizationTasks[name].BeadFixedRegion

        Parameters
        ----------
        name
            A String specifying the geometric restriction repository key.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the geometric restriction is applied.
        csys
            None or a DatumCsys object specifying the local coordinate system. If **csys** = None, the
            global coordinate system is used. When this member is queried, it returns an Int. The
            default value is None.
        u1
            A Boolean specifying whether to fix the region in the 1-direction. The default value is
            OFF.
        u2
            A Boolean specifying whether to fix the region in the 2-direction. The default value is
            OFF.
        u3
            A Boolean specifying whether to fix the region in the 3-direction. The default value is
            OFF.

        Returns
        -------
        BeadFixedRegion
            A :py:class:`~abaqus.Optimization.BeadFixedRegion.BeadFixedRegion` object.
        """
        super().__init__()
        pass

    def setValues(
        self, csys: int = None, u1: Boolean = OFF, u2: Boolean = OFF, u3: Boolean = OFF
    ):
        """This method modifies the BeadFixedRegion object.

        Parameters
        ----------
        csys
            None or a DatumCsys object specifying the local coordinate system. If **csys** = None, the
            global coordinate system is used. When this member is queried, it returns an Int. The
            default value is None.
        u1
            A Boolean specifying whether to fix the region in the 1-direction. The default value is
            OFF.
        u2
            A Boolean specifying whether to fix the region in the 2-direction. The default value is
            OFF.
        u3
            A Boolean specifying whether to fix the region in the 3-direction. The default value is
            OFF.
        """
        pass



from abaqusConstants import *
from .Leaf import Leaf


class LeafFromNodeLabels(Leaf):
    """The LeafFromNodeLabels object can be used whenever a Leaf object is expected as an
    argument. Leaf objects are used to specify the items in a display group. Leaf objects
    are constructed as temporary objects, which are then used as arguments to DisplayGroup
    commands.
    The LeafFromNodeLabels object is derived from the Leaf object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import displayGroupOdbToolset
    """

    #: A SymbolicConstant specifying the leaf type. Possible values are EMPTY_LEAF,
    #: DEFAULT_MODEL, ALL_ELEMENTS, ALL_NODES, and ALL_SURFACES.
    leafType: SymbolicConstant = None

    #: A String specifying the name of the part instance to which **nodeLabels** refers.
    partInstanceName: str

    #: A sequence of Strings specifying expressions that denote node labels. The expression can
    #: be any of the following:An Int specifying a single node label; for example, `1`.A String
    #: specifying a single node label; for example, `'7'`.A String specifying a sequence of
    #: node labels; for example, `'3:5'` and `'3:15:3'`.
    nodeLabels: tuple

    def __init__(self, partInstanceName: str, nodeLabels: tuple):
        """This method creates a Leaf object from a sequence of node labels that belong to a single
        part instance.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                LeafFromNodeLabels

        Parameters
        ----------
        partInstanceName
            A String specifying the name of the part instance to which **nodeLabels** refers.
        nodeLabels
            A sequence of Strings specifying expressions that denote node labels. The expression can
            be any of the following:An Int specifying a single node label; for example, `1`.A String
            specifying a single node label; for example, `'7'`.A String specifying a sequence of
            node labels; for example, `'3:5'` and `'3:15:3'`.

        Returns
        -------
        LeafFromNodeLabels
            A :py:class:`~abaqus.DisplayGroup.LeafFromNodeLabels.LeafFromNodeLabels` object.
        """
        super().__init__(DEFAULT_MODEL)
        pass



from abaqusConstants import *
from .InteractionState import InteractionState


class CyclicSymmetryState(InteractionState):
    """The CyclicSymmetryState object stores the propagating data for a CyclicSymmetry object.
    One instance of this object is created internally by the CyclicSymmetry object for each
    step. The instance is also deleted internally by the CyclicSymmetry object.
    The CyclicSymmetryState object has no constructor or methods.
    The CyclicSymmetryState object is derived from the InteractionState object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].steps[name].interactionStates[name]

        The corresponding analysis keywords are:

        - CLOAD
                - DLOAD
                - DSLOAD
                - SELECT CYCLIC SYMMETRY MODES
    """

    #: A SymbolicConstant specifying whether Abaqus should extract all possible nodal diameters
    #: or the nodal diameters between the user-specified values for **lowestNodalDiameter** and
    #: **highestNodalDiameter**. Possible values are ALL_NODAL_DIAMETER and
    #: SPECIFIED_NODAL_DIAMETER. The default value is ALL_NODAL_DIAMETER.
    extractedNodalDiameter: SymbolicConstant = ALL_NODAL_DIAMETER

    #: A SymbolicConstant specifying the propagation state of the **extractedNodalDiameter**
    #: member. Possible values are UNSET, SET, UNCHANGED, and FREED.
    extractedNodalDiameterState: SymbolicConstant = None

    #: An Int specifying the lowest nodal diameter to be used in the eigenfrequency analysis.
    #: The default value is 0.
    lowestNodalDiameter: int = 0

    #: A SymbolicConstant specifying the propagation state of the **lowestNodalDiameter** member.
    #: Possible values are UNSET, SET, UNCHANGED, and FREED.
    lowestNodalDiameterState: SymbolicConstant = None

    #: An Int specifying the highest nodal diameter to be used in the eigenfrequency analysis.
    #: This argument value should be less than or equal to the half of the total number of
    #: sectors. The default value is 0.
    highestNodalDiameter: int = 0

    #: A SymbolicConstant specifying the propagation state of the **highestNodalDiameter**
    #: member. Possible values are UNSET, SET, UNCHANGED, and FREED.
    highestNodalDiameterState: SymbolicConstant = None

    #: An Int specifying the nodal diameter for which the modal-based steady-state dynamic
    #: analysis will be performed. This value should be greater than or equal to the lowest
    #: nodal diameter (specified in the **lowestNodalDiameter** parameter), and less than or
    #: equal to the highest nodal diameter (specified in the **highestNodalDiameter** parameter).
    #: The default value is 0.
    excitiationNodalDiameter: int = 0

    #: A SymbolicConstant specifying the propagation state of the **excitiationNodalDiameter**
    #: member. Possible values are UNSET, SET, UNCHANGED, and FREED.
    excitiationNodalDiameterState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the InteractionState object.
    #: Possible values are:
    #: 
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: SymbolicConstant = None



import typing

from abaqusConstants import *


class SurfaceFeatureAssignment:
    """The SurfaceFeatureAssignment object stores the surface feature angle assignment
    definition for surfaces in ContactExp or ContactStd objects. The
    SurfaceFeatureAssignment object has no constructor or members.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].interactions[name].surfaceFeatureAssignments

        The corresponding analysis keywords are:

        - SURFACE PROPERTY ASSIGNMENT
    """

    def changeValuesInStep(
        self, stepName: str, index: int, value: typing.Union[SymbolicConstant, float]
    ):
        """This method allows modification of surface feature angle assignments already defined on
        surfaces in a given step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the surface feature assignments are to
            be modified.
        index
            An Int specifying the position of the surface feature angle assignment whose value is to
            be modified.
        value
            A tuple specifying the value of the surface feature assignments for the surface whose
            index is referenced. Each tuple contains two entries for Abaqus/Standard and three
            entries for Abaqus/Explicit:
            
            - A Float or a SymbolicConstant specifying the overriding surface primary feature angle
              value to be used for the surface. Possible values of the SymbolicConstant are PERIMETER,
              ALL, PICKED, or NONE. The ALL and PICKED values cannot be specified with the GLOBAL
              region constant and can be used only in the Abaqus/Explicit version of general contact.
            - A Float or a SymbolicConstant specifying the overriding surface slave feature
              angle value to be used for the surface. Possible values of the SymbolicConstant are
              PERIMETER, ALL, PICKED, or NONE. The ALL and PICKED values cannot be specified with the
              GLOBAL region constant and can be used only in the Abaqus/Explicit version of general
              contact.
            - A SymbolicConstant ORIGINAL or CURRENT specifying the configuration.
        """
        pass

    def appendInStep(
        self, stepName: str, assignments: typing.Union[SymbolicConstant, float]
    ):
        """This method allows addition of surface feature angle assignments to new surfaces in a
        given step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which new surface feature angle assignments
            are to be defined.
        assignments
            A sequence of tuples specifying the surface feature angle assignments. Each tuple
            contains three entries for Abaqus/Standard and four entries for Abaqus/Explicit:
            - A region object or the SymbolicConstant GLOBAL specifying the surface to which the
              feature angle is assigned.
            - A Float or a SymbolicConstant specifying the overriding surface primary feature angle
              value to be used for the surface. Possible values of the SymbolicConstant are PERIMETER,
              ALL, PICKED, or NONE. The ALL and PICKED values cannot be specified with the GLOBAL
              region constant and can be used only in the Abaqus/Explicit version of general contact.
            - A Float or a SymbolicConstant specifying the overriding surface secondary feature
              angle value to be used for the surface. Possible values of the SymbolicConstant are
              PERIMETER, ALL, PICKED, or NONE. The ALL and PICKED values cannot be specified with the
              GLOBAL region constant and can be used only in the Abaqus/Explicit version of general
              contact.
            - A SymbolicConstant ORIGINAL or CURRENT specifying the configuration.
        """
        pass

    def delete(self, indices: tuple):
        """The delete method allows you to delete existing surface feature angle assignments from a
        ContactExp object.

        Parameters
        ----------
        indices
            A sequence of Ints specifying the index of each surface feature angle assignment to
            delete.
        """
        pass



from abaqusConstants import *
from .LoadState import LoadState


class ConcentratedChargeState(LoadState):
    """The ConcentratedChargeState object stores the propagating data of a concentrated charge
    in a step. One instance of this object is created internally by the ConcCharge object
    for each step. The instance is also deleted internally by the ConcCharge object.
    The ConcentratedChargeState object has no constructor or methods.
    The ConcentratedChargeState object is derived from the LoadState object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].steps[name].loadStates[name]

        The corresponding analysis keywords are:

        - CECHARGE
    """

    #: A Float specifying the load magnitude.
    magnitude: float = None

    #: A SymbolicConstant specifying the propagation state of the load magnitude. Possible
    #: values are UNSET, SET, UNCHANGED, and FREED.
    magnitudeState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the **amplitude** member. Possible
    #: values are UNSET, SET, UNCHANGED, and FREED.
    amplitudeState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the LoadState object. Possible
    #: values are:
    #: 
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: SymbolicConstant = None

    #: A String specifying the name of the amplitude reference. The String is empty if the load
    #: has no amplitude reference.
    amplitude: str = ""



class JouleHeatFraction:
    """The JouleHeatFraction object defines the fraction of electric energy released as heat.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].jouleHeatFraction
            import odbMaterial
            session.odbs[name].materials[name].jouleHeatFraction

        The corresponding analysis keywords are:

        - JOULE HEAT FRACTION
    """

    def __init__(self, fraction: float = 1):
        """This method creates a JouleHeatFraction object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].JouleHeatFraction
                session.odbs[name].materials[name].JouleHeatFraction

        Parameters
        ----------
        fraction
            A Float specifying the fraction of electrical energy released as heat, including any
            unit conversion factor. The default value is 1.0.

        Returns
        -------
        JouleHeatFraction
            A :py:class:`~abaqus.Material.Others.HeatTransfer.JouleHeatFraction.JouleHeatFraction` object.

        Raises
        ------
        RangeError
        """
        pass

    def setValues(self, *args, **kwargs):
        """This method modifies the JouleHeatFraction object.

        Raises
        ------
        RangeError
        """
        pass



from .Crack import Crack
from .Fastener import Fastener
from .Inertia import Inertia
from .SpringDashpot import SpringDashpot
from ..Region.Region import Region


class EngineeringFeatureBase:
    """The EngineeringFeature object is a container for various specific engineering feature
    repositories. The EngineeringFeature object has no explicit constructor or methods.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import part
            mdb.models[name].parts[name].engineeringFeatures
            import assembly
            mdb.models[name].rootAssembly.engineeringFeatures
    """

    #: A repository of Inertia objects.
    inertias: dict[str, Inertia] = dict[str, Inertia]()

    #: A repository of Crack objects.
    cracks: dict[str, Crack] = dict[str, Crack]()

    #: A repository of Fastener objects.
    fasteners: dict[str, Fastener] = dict[str, Fastener]()

    #: A repository of SpringDashpot objects.
    springDashpots: dict[str, SpringDashpot] = dict[str, SpringDashpot]()

    def assignSeam(self, regions: tuple[Region]):
        """This method creates a seam crack along an edge or a face.

        Parameters
        ----------
        regions
            A sequence of Region objects specifying the domain of the seam crack. The Region objects
            must be faces or edges.
        """
        pass

    def deleteSeam(self, regions: tuple[Region]):
        """This method deletes a seam crack.

        Parameters
        ----------
        regions
            A sequence of Region objects specifying the domain of the seam crack. The Region objects
            must be faces or edges.
        """
        pass



from ..Animation.AnimationSession import AnimationSession
from ..DisplayGroup.DisplayGroupSession import DisplayGroupSession
from ..FieldReport.FieldReportSession import FieldReportSession
from ..Job.JobSession import JobSession
from ..Odb.OdbSession import OdbSession
from ..PathAndProbe.PathSession import PathSession
from ..XY.XYSession import XYSession


class Session(
    AnimationSession,
    DisplayGroupSession,
    FieldReportSession,
    JobSession,
    OdbSession,
    PathSession,
    XYSession,
):
    """The Session object has no constructor. Abaqus creates the **session** member when a
    session is started.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            session
    """

    pass



from abaqusConstants import *
from .DataTableArray import DataTableArray
from .DiscreteField import DiscreteField
from .ExpressionField import ExpressionField
from .MappedField import MappedField
from ..Model.ModelBase import ModelBase


class FieldModel(ModelBase):
    def DiscreteField(
        self,
        name: str,
        defaultValues: tuple,
        fieldType: SymbolicConstant,
        location: SymbolicConstant = NODES,
        dataWidth: int = 1,
        data: DataTableArray = None,
        description: str = "",
        orientationType: SymbolicConstant = CARTESIAN,
        partLevelOrientation: Boolean = OFF,
    ) -> DiscreteField:
        """This method creates a DiscreteField object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].DiscreteField

        Parameters
        ----------
        name
            A String specifying the repository key.
        defaultValues
            A sequence of Floats specifying a sequence of floats specifying the default values.
        fieldType
            A SymbolicConstant or an Int specifying the type of data represented by this discrete
            field. Possible values are SCALAR, ORIENTATION, and PRESCRIBEDCONDITION_DOF.
        location
            A SymbolicConstant or an Int specifying the location of the domain data. Possible values
            are NODES and ELEMENTS. The default value is NODES.
        dataWidth
            An Int specifying the width of the supplied data. The default value is 1.
        data
            A :py:class:`~abaqus.Field.DataTableArray.DataTableArray` object.
        description
            A String specifying the description of the field. The default value is an empty string.
        orientationType
            A SymbolicConstant specifying the type of the system being described by a discrete field
            used for an orientation. Possible values are CARTESIAN, CYLINDRICAL, and SPHERICAL. The
            default value is CARTESIAN.
        partLevelOrientation
            A Boolean specifying whether or not the orientations are described in terms of part
            level coordinates. The default value is OFF.

        Returns
        -------
        DiscreteField
            A :py:class:`~abaqus.Field.DiscreteField.DiscreteField` object.

        Raises
        ------
        AbaqusException
        """
        self.discreteFields[name] = discreteField = DiscreteField(
            name,
            defaultValues,
            fieldType,
            location,
            dataWidth,
            data,
            description,
            orientationType,
            partLevelOrientation,
        )
        return discreteField

    def ExpressionField(
        self, name: str, expression: str, localCsys: str = None, description: str = ""
    ) -> ExpressionField:
        """This method creates an ExpressionField object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].ExpressionField

        Parameters
        ----------
        name
            A String specifying the repository key.
        expression
            A String specifying the Python expression to evaluate in space. Variables are X, Y, and
            Z; R, Th, and Z; or R, Th, and P based on the selected coordinate system.
        localCsys
            None or a DatumCsys object specifying the local coordinate system of the field. If
            **localCsys** = None, the field is defined in the global coordinate system. The default
            value is None.
        description
            A String specifying the description of the field. The default value is an empty string.

        Returns
        -------
        ExpressionField
            An :py:class:`~abaqus.Field.ExpressionField.ExpressionField` object.

        Raises
        ------
        TextException
        """
        self.analyticalFields[name] = expressionField = ExpressionField(
            name, expression, localCsys, description
        )
        return expressionField

    def MappedField(
        self,
        name: str,
        regionType: SymbolicConstant = POINT,
        partLevelData: Boolean = OFF,
        pointDataFormat: SymbolicConstant = XYZ,
        gridPointPlane: SymbolicConstant = XYPLANE,
        defaultUnMappedValue: float = 0,
        mappingAlgorithm: SymbolicConstant = SURFACE,
        searchTolType: SymbolicConstant = RELATIVE,
        boundarySearchTol: float = 0,
        neighborhoodSearchTol: float = 1000000,
        negativeNormalSearchTol: float = 0,
        positiveNormalSearchTol: float = 0,
        scaleCoordinates: Boolean = OFF,
        gridPointData: tuple = (),
        xyzPointData: tuple = (),
        coordinateScalingFactors: tuple = (),
        localCsys: str = None,
        description: str = "",
    ) -> MappedField:
        """This method creates an MappedField object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].MappedField

        Parameters
        ----------
        name
            A String specifying the repository key.
        regionType
            A SymbolicConstant specifying the data source region type. It can be either an ODB mesh
            or a cloud of points. Possible values are MESH and POINT. The default value is POINT.
        partLevelData
            A Boolean specifying whether or not the point cloud source data are described in terms
            of part level coordinates. If part level coordinates is employed, the local coordinate
            system defined in **localCsys** will be ignored. The default value is OFF.
        pointDataFormat
            A SymbolicConstant specifying point cloud source data format. Possible values are GRID
            and XYZ. The default value is XYZ.
        gridPointPlane
            A SymbolicConstant specifying the plane on which the point cloud source data of grid
            format are described. Possible values are XYPLANE, YZPLANE, and XZPLANE. The default
            value is XYPLANE.
        defaultUnMappedValue
            A Float specifying the parameter (field) value reported when a value cannot be
            calculated from the data source. The default value is 0.0.
        mappingAlgorithm
            A SymbolicConstant specifying the mapping algorithm for target surface, or on mesh
            target model when the parameter value are located at nodes, for example nodal
            temperatures. Possible values are SURFACE and VOLUMETRIC. The default value is SURFACE.
        searchTolType
            A SymbolicConstant specifying searching tolerance type in terms of absolute value or a
            fraction of the average of all element characteristic length in target model region.
            Possible values are ABSOLUTE and RELATIVE. The default value is RELATIVE.
        boundarySearchTol
            A Float specifying the search distance tolerance value on the exterior boundary of
            target model region. Source points within this distance will be included in computing
            the parameter value of target region. This tolerance applies to both surface and
            volumetric mapping. The default value is 0.01.
        neighborhoodSearchTol
            A Float specifying the search distance tolerance value used for distance weighting
            algorithm. Source points within this distance will be included in computing the
            parameter value of target region. This tolerance only applies to surface mapping. The
            default value is 1000000.0.
        negativeNormalSearchTol
            A Float specifying the search distance tolerance value in the negative normal of target
            surface region. Source points within this distance will be included in computing the
            parameter value of target region. This tolerance only applies to surface mapping. The
            default value is 0.15.
        positiveNormalSearchTol
            A Float specifying the search distance tolerance value in the positive normal of target
            surface region. Source points within this distance will be included in computing the
            parameter value of target region. This tolerance only applies to surface mapping. The
            default value is 0.05.
        scaleCoordinates
            A Boolean specifying whether or not to scale the user-supplied coordinate values from
            the point cloud or indicated ODB. The default value is OFF.
        gridPointData
            A sequence of sequences of Floats specifying the point cloud source data of grid format.
            The default value is an empty sequence.
        xyzPointData
            A sequence of sequences of Floats specifying the point cloud source data of XYZ format.
            Each data item is defining the XYZ coordinates of a point and its field value. The
            default value is an empty sequence.
        coordinateScalingFactors
            A sequence of Floats specifying the scaling factors for the global 1, 2 and 3
            directions. The default value is (1.0, 1.0, 1.0).
        localCsys
            None or a DatumCsys object specifying the local coordinate system of the field. If
            **localCsys** = None, the field is defined in the global coordinate system. The default
            value is None.
        description
            A String specifying the description of the field. The default value is an empty string.

        Returns
        -------
        MappedField
            A :py:class:`~abaqus.Field.MappedField.MappedField` object.

        Raises
        ------
        AbaqusException
        """
        self.analyticalFields[name] = mappedField = MappedField(
            name,
            regionType,
            partLevelData,
            pointDataFormat,
            gridPointPlane,
            defaultUnMappedValue,
            mappingAlgorithm,
            searchTolType,
            boundarySearchTol,
            neighborhoodSearchTol,
            negativeNormalSearchTol,
            positiveNormalSearchTol,
            scaleCoordinates,
            gridPointData,
            xyzPointData,
            coordinateScalingFactors,
            localCsys,
            description,
        )
        return mappedField



class OdbDataNodeSet:
    """The OdbDataNodeSet object stores node set data.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
            session.odbData[name].nodeSets[i]
    """

    #: A String specifying the set name. This attribute is read-only.
    name: str = ""

    #: A String-to-tuple-of-Ints Dictionary specifying the nodes in the set. This attribute is
    #: read-only.
    nodes: str = ""



from abaqusConstants import *
from .LoadState import LoadState


class BodyHeatFluxState(LoadState):
    """The BodyHeatFluxState object stores the propagating data for a Body BodyHeatFlux object
    in a step. One instance of this object is created internally by the BodyHeatFlux object
    for each step. The instance is also deleted internally by the BodyHeatFlux object.
    The BodyHeatFluxState object has no constructor or methods.
    The BodyHeatFluxState object is derived from the LoadState object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].steps[name].loadStates[name]

        The corresponding analysis keywords are:

        - DFLUX
    """

    #: A Float specifying the Body heat flux magnitude.
    magnitude: float = None

    #: A SymbolicConstant specifying the propagation state of the Body heat flux magnitude.
    #: Possible values are UNSET, SET, UNCHANGED, and MODIFIED.
    magnitudeState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the **amplitude** member. Possible
    #: values are UNSET, SET, UNCHANGED, and FREED.
    amplitudeState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the LoadState object. Possible
    #: values are:
    #: 
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: SymbolicConstant = None

    #: A String specifying the name of the amplitude reference. The String is empty if the load
    #: has no amplitude reference.
    amplitude: str = ""



from abaqusConstants import *


class Density:
    """The Density object specifies the material density.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].density
            import odbMaterial
            session.odbs[name].materials[name].density

        The table data for this object are:

        - The mass density.
        - Temperature, if the data depend on temperature.
        - Value of the first field variable, if the data depend on field variables.
        - Value of the second field variable.
        - Etc.

        The corresponding analysis keywords are:

        - DENSITY
    """

    def __init__(
        self,
        table: tuple,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        distributionType: SymbolicConstant = UNIFORM,
        fieldName: str = "",
    ):
        """This method creates a Density object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].Density
                session.odbs[name].materials[name].Density

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.
        distributionType
            A SymbolicConstant specifying how the density is distributed spatially. Possible values
            are UNIFORM, ANALYTICAL_FIELD, and DISCRETE_FIELD. The default value is UNIFORM.
        fieldName
            A String specifying the name of the AnalyticalField or DiscreteField object associated
            with this material option. The **fieldName** argument applies only when
            **distributionType** = ANALYTICAL_FIELD or **distributionType** = DISCRETE_FIELD. The default
            value is an empty string.

        Returns
        -------
        Density
            A :py:class:`~abaqus.Material.Density.Density.Density` object.

        Raises
        ------
        RangeError
        """
        pass

    def setValues(self, *args, **kwargs):
        """This method modifies the Density object.

        Raises
        ------
        RangeError
        """
        pass



from abaqusConstants import *
from ..PlotOptions.DGContourOptions import DGContourOptions


class ContourOptions(DGContourOptions):
    """The ContourOptions object stores values and attributes associated with a contour plot.
    The ContourOptions object has no constructor command. Abaqus creates a
    *defaultOdbDisplay.contourOptions* member when you import the Visualization module.
    Abaqus creates a **contourOptions** member when it creates the OdbDisplay object, using
    the values from *defaultOdbDisplay.contourOptions*. Abaqus creates the **odbDisplay**
    member when a viewport is created, using the values from **defaultOdbDisplay**.
    ContourOptions objects are accessed in one of two ways:
    - The default contour options. These settings are used as defaults when other
    **contourOptions** members are created. These settings can be set to customize user
    preferences.
    - The contour options associated with a particular viewport.
    The ContourOptions object is derived from the DGContourOptions object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
            session.defaultOdbDisplay.contourOptions
            session.viewports[name].assemblyDisplay.displayGroupInstances[name].odbDisplayOptions.contourOptions
            session.viewports[name].layers[name].assemblyDisplay.displayGroupInstances[name].odbDisplayOptions.contourOptions
            session.viewports[name].layers[name].odbDisplay.contourOptions
            session.viewports[name].layers[name].odbDisplay.displayGroupInstances[name].odbDisplayOptions.contourOptions
            session.viewports[name].layers[name].partDisplay.displayGroupInstances[name].odbDisplayOptions.contourOptions
            session.viewports[name].odbDisplay.contourOptions
            session.viewports[name].odbDisplay.displayGroupInstances[name].odbDisplayOptions.contourOptions
            session.viewports[name].partDisplay.displayGroupInstances[name].odbDisplayOptions.contourOptions
    """

    #: A SymbolicConstant specifying the contour type. Possible values are LINE, BANDED, QUILT,
    #: and ISOSURFACE. The default value is BANDED.
    contourType: SymbolicConstant = BANDED

    #: An Int specifying the number of intervals when **contourStyle** = UNIFORM. Possible values
    #: are 2 ≤≤ **numIntervals** ≤≤ 24. The default value is 12.
    numIntervals: int = 12

    #: A SymbolicConstant specifying the interval type of the contour plot. Possible values are
    #: UNIFORM, LOG, and USER_DEFINED. The default value is UNIFORM.
    intervalType: SymbolicConstant = UNIFORM

    #: A Boolean specifying whether the contour range maximum value should be computed from the
    #: output data to be contoured. The default value is ON.
    maxAutoCompute: Boolean = ON

    #: A Float specifying the contour range maximum value to be used in the plot when
    #: **maxAutoCompute** = ON. The default value is **autoMaxValue**.
    maxValue: float = None

    #: A Boolean specifying whether the contour range minimum value should be computed from the
    #: output data to be contoured. The default value is ON.
    minAutoCompute: Boolean = ON

    #: A Float specifying the contour range minimum value to be used in the plot when
    #: **minAutoCompute** = ON. The default value is **autoMinValue**.
    minValue: float = None

    #: A SymbolicConstant specifying the method to be used when contour limits are
    #: automatically computed for animation. **animationAutoLimits** will only effect the minimum
    #: limit and/or maximum limit when **minAutoCompute** and/or **maxAutoCompute** = True. Possible
    #: values are FIRST_AND_LAST, CURRENT_FRAME, RECOMPUTE_EACH_FRAME, and ALL_FRAMES. The
    #: default value is ALL_FRAMES.
    animationAutoLimits: SymbolicConstant = ALL_FRAMES

    #: A SymbolicConstant specifying the color of contour values that exceed the limits of the
    #: plot. Possible values are SPECTRUM and SPECIFY.When **outsideLimitsMode** = SPECTRUM, the
    #: maximum and minimum contour spectrum colors are used for values that exceed the limits
    #: of the plot. When **outsideLimitsMode** = SPECIFY, the values of **outsideLimitsAboveColor**
    #: and **outsideLimitsBelowColor** are used for values that exceed the limits of the plot.
    outsideLimitsMode: SymbolicConstant = None

    #: A Boolean specifying whether to auto-compute contour limits using extrapolated values
    #: alone or extrapolated values that are averaged. The default value is OFF.
    extrapolatedAveraging: Boolean = OFF

    #: A Boolean specifying whether to display location of maximum value. The default value is
    #: OFF.
    showMaxLocation: Boolean = OFF

    #: A Boolean specifying whether to display location of minimum value. The default value is
    #: OFF.
    showMinLocation: Boolean = OFF

    #: A Float specifying the maximum value to be used in the plot. The value is computed from
    #: the output data to be contoured. This value is read-only.
    autoMaxValue: float = None

    #: A Float specifying the minimum value to be used in the plot. The value is computed from
    #: the output data to be contoured. This value is read-only.
    autoMinValue: float = None

    #: A String specifying the color to be used for values that exceed the limits of the plot
    #: when **outsideLimitsMode** = SPECIFY. The default value is "Grey80".
    outsideLimitsAboveColor: str = ""

    #: A String specifying the color to be used for values that exceed the limits of the plot
    #: when **outsideLimitsMode** = SPECIFY. The default value is "Grey20".
    outsideLimitsBelowColor: str = ""

    #: A String specifying the name of the color spectrum to be used in the contour plot. The
    #: default value is "Rainbow".
    spectrum: str = ""
    
    #: A Boolean specifying whether the contour legend should show the lowest value at the top
    #: and the highest value at the bottom (**reversedContourLegendRange=ON**) or vice versa. The
    #: default value is OFF.
    reversedContourLegendRange: Boolean = OFF

    #: A tuple of Floats specifying the interval values when **intervalType** = USER_DEFINED.
    intervalValues: float = None

    #: A SymbolicConstant specifying the contour rendering method. Possible values are
    #: TEXTURE_MAPPED and TESSELLATED. The default value is TEXTURE_MAPPED.
    contourMethod: SymbolicConstant = TEXTURE_MAPPED

    #: A Boolean specifying whether tick mark plots should be displayed on line-type elements.
    #: If **tickmarkPlots** = ON, Abaqus displays a tick mark plot. If **tickmarkPlots** = OFF, Abaqus
    #: displays contours on the element faces. The default value is OFF.
    tickmarkPlots: Boolean = OFF

    #: A SymbolicConstant specifying the interval style of the contour plot. Possible values
    #: are CONTINUOUS and UNIFORM. The default value is UNIFORM.
    contourStyle: SymbolicConstant = UNIFORM

    #: A Boolean specifying whether to plot the edges of each contour interval when
    #: **contourType** = BANDED or ISOSURFACE. The default value is OFF.
    contourEdges: Boolean = OFF

    #: A SymbolicConstant specifying the edge line style to be used to plot the contour edges
    #: when **contourType** = BANDED or ISOSURFACE. Possible values are SOLID, DASHED, DOTTED, and
    #: DOT_DASH. The default value is SOLID.
    contourEdgeStyle: SymbolicConstant = SOLID

    #: A SymbolicConstant specifying the edge line thickness to be used to plot the edge of the
    #: contour intervals when **contourType** = BANDED or ISOSURFACE. Possible values are
    #: VERY_THIN, THIN, MEDIUM, and THICK. The default value is VERY_THIN.
    contourEdgeThickness: SymbolicConstant = VERY_THIN

    #: A Boolean specifying the display of the nodal averaged coordinate systems used when
    #: averaging element vector or tensor data. The default value is OFF.
    averagedOrientationDisplay: Boolean = OFF

    #: A Boolean specifying whether the label for the matching ply shows up in the viewport.
    #: The default value is OFF.
    matchingPlyLabels: Boolean = OFF

    #: A Boolean specifying whether the contour color is driven by the matching ply. The
    #: default value is OFF.
    colorByMatchingPlies: Boolean = OFF

    #: A SymbolicConstant specifying the length of the tick mark plot axes. Possible values are
    #: SHORT, MEDIUM, and LONG. The default value is MEDIUM.
    tickmarkAxisLength: SymbolicConstant = MEDIUM

    #: A Float specifying the base contour value defining the tick mark axis contour value that
    #: intersects the elements. Possible values are **autoMinValue** ≤≤ **tickmarkBaseValue** ≤≤
    #: **autoMaxValue**. The default value is 0.0.
    tickmarkBaseValue: float = 0

    #: A SymbolicConstant specifying the orientation of the tick mark plots. Possible values
    #: are N1 and N2. The default value is N2.
    tickmarkOrientation: SymbolicConstant = N2

    #: A String specifying the edge color to be used when **contourType** = LINE. The default value
    #: is "White".
    edgeColorLine: str = ""

    #: A String specifying the edge color to be used when **contourType** = BANDED or QUILT. The
    #: default value is "Black".
    edgeColorBandedQuilt: str = ""

    #: A String specifying the color to be used to plot the contour edges when
    #: **contourType** = BANDED or ISOSURFACE. The default value is "Grey60".
    contourEdgeColor: str = ""

    #: A String specifying the color to be used to plot the tick mark curve. The default value
    #: is "Cyan".
    tickmarkCurveColor: str = ""

    #: A tuple of tuples of SymbolicConstants specifying the line style and line thickness for
    #: each interval in the plot when **contourType** = LINE. The size of the outer sequence must
    #: be equal to **numIntervals**-1. The inner sequence consists of two SymbolicConstants
    #: specifying the line style and line thickness. For possible values, refer to the
    #: **edgeLineStyle** and **edgeLineThickness** members of the DGCommonOptions object. The
    #: default is ((SOLID, VERY_THIN), ).
    intervalLineAttributes: SymbolicConstant = None

    #: A Boolean specifying whether to hide the values outside the specified min/max in the
    #: contour legend. This setting hides the *autoMinValue* and *autoMaxValue* from the
    #: spectrum when *legendHideOutsideLimits*=ON.The default value is OFF.
    legendHideOutsideLimits: Boolean = OFF

    def setValues(
        self,
        options: "ContourOptions" = None,
        contourType: SymbolicConstant = BANDED,
        contourMethod: SymbolicConstant = TEXTURE_MAPPED,
        tickmarkPlots: Boolean = OFF,
        contourStyle: SymbolicConstant = UNIFORM,
        numIntervals: int = 12,
        intervalType: SymbolicConstant = UNIFORM,
        intervalValues: tuple = (),
        maxAutoCompute: Boolean = ON,
        maxValue: float = None,
        minAutoCompute: Boolean = ON,
        minValue: float = None,
        animationAutoLimits: SymbolicConstant = ALL_FRAMES,
        edgeColorLine: str = "",
        edgeColorBandedQuilt: str = "",
        spectrum: str = "",
        reversedContourLegendRange: Boolean = OFF,
        outsideLimitsMode: SymbolicConstant = None,
        outsideLimitsAboveColor: str = "",
        outsideLimitsBelowColor: str = "",
        intervalLineAttributes: SymbolicConstant = None,
        contourEdges: Boolean = OFF,
        contourEdgeColor: str = "",
        contourEdgeStyle: SymbolicConstant = SOLID,
        contourEdgeThickness: SymbolicConstant = VERY_THIN,
        tickmarkAxisLength: SymbolicConstant = MEDIUM,
        tickmarkBaseValue: float = 0,
        tickmarkOrientation: SymbolicConstant = N2,
        tickmarkCurveColor: str = "",
        averagedOrientationDisplay: Boolean = OFF,
        extrapolatedAveraging: Boolean = OFF,
        showMaxLocation: Boolean = OFF,
        showMinLocation: Boolean = OFF,
        legendHideOutsideLimits: Boolean = OFF,
    ):
        """This method modifies the ContourOptions object.

        Parameters
        ----------
        options
            A :py:class:`~abaqus.OdbDisplay.ContourOptions.ContourOptions` object from which values are to be copied. If other arguments are also
            supplied to setValues, they will override the values in **options**. The default value is
            None.
        contourType
            A SymbolicConstant specifying the contour type. Possible values are LINE, BANDED, QUILT,
            and ISOSURFACE. The default value is BANDED.
        contourMethod
            A SymbolicConstant specifying the contour rendering method. Possible values are
            TEXTURE_MAPPED and TESSELLATED. The default value is TEXTURE_MAPPED.
        tickmarkPlots
            A Boolean specifying whether tick mark plots should be displayed on line-type elements.
            If **tickmarkPlots** = ON, Abaqus displays a tick mark plot. If **tickmarkPlots** = OFF, Abaqus
            displays contours on the element faces. The default value is OFF.
        contourStyle
            A SymbolicConstant specifying the interval style of the contour plot. Possible values
            are CONTINUOUS and UNIFORM. The default value is UNIFORM.
        numIntervals
            An Int specifying the number of intervals when **contourStyle** = UNIFORM. Possible values
            are 2 ≤≤ **numIntervals** ≤≤ 24. The default value is 12.
        intervalType
            A SymbolicConstant specifying the interval type of the contour plot. Possible values are
            UNIFORM, LOG, and USER_DEFINED. The default value is UNIFORM.
        intervalValues
            A sequence of Floats specifying the interval values when **intervalType** = USER_DEFINED.
        maxAutoCompute
            A Boolean specifying whether the contour range maximum value should be computed from the
            output data to be contoured. The default value is ON.
        maxValue
            A Float specifying the contour range maximum value to be used in the plot when
            **maxAutoCompute** = ON. The default value is **autoMaxValue**.
        minAutoCompute
            A Boolean specifying whether the contour range minimum value should be computed from the
            output data to be contoured. The default value is ON.
        minValue
            A Float specifying the contour range minimum value to be used in the plot when
            **minAutoCompute** = ON. The default value is **autoMinValue**.
        animationAutoLimits
            A SymbolicConstant specifying the method to be used when contour limits are
            automatically computed for animation. **animationAutoLimits** will only effect the minimum
            limit and/or maximum limit when **minAutoCompute** and/or **maxAutoCompute** = True. Possible
            values are FIRST_AND_LAST, CURRENT_FRAME, RECOMPUTE_EACH_FRAME, and ALL_FRAMES. The
            default value is ALL_FRAMES.
        edgeColorLine
            A String specifying the edge color to be used when **contourType** = LINE. The default value
            is "White".
        edgeColorBandedQuilt
            A String specifying the edge color to be used when **contourType** = BANDED or QUILT. The
            default value is "Black".
        spectrum
            A String specifying the name of the color spectrum to be used in the contour plot. The
            default value is "Rainbow".
        reversedContourLegendRange
            A Boolean specifying whether the contour legend should show the lowest value at the top
            and the highest value at the bottom (*reversedContourLegendRange*=ON) or vice versa. The
            default value is OFF.
        outsideLimitsMode
            A SymbolicConstant specifying the color of contour values that exceed the limits of the
            plot. Possible values are SPECTRUM and SPECIFY.When **outsideLimitsMode** = SPECTRUM, the
            maximum and minimum contour spectrum colors are used for values that exceed the limits
            of the plot. When **outsideLimitsMode** = SPECIFY, the values of **outsideLimitsAboveColor**
            and **outsideLimitsBelowColor** are used for values that exceed the limits of the plot.
        outsideLimitsAboveColor
            A String specifying the color to be used for values that exceed the limits of the plot
            when **outsideLimitsMode** = SPECIFY. The default value is "Grey80".
        outsideLimitsBelowColor
            A String specifying the color to be used for values that exceed the limits of the plot
            when **outsideLimitsMode** = SPECIFY. The default value is "Grey20".
        intervalLineAttributes
            A sequence of sequences of SymbolicConstants specifying the line style and line
            thickness for each interval in the plot when **contourType** = LINE. The size of the outer
            sequence must be equal to **numIntervals**-1. The inner sequence consists of two
            SymbolicConstants specifying the line style and line thickness. For possible values,
            refer to the **edgeLineStyle** and **edgeLineThickness** members of the DGCommonOptions
            object. The default is ((SOLID, VERY_THIN), ).
        contourEdges
            A Boolean specifying whether to plot the edges of each contour interval when
            **contourType** = BANDED or ISOSURFACE. The default value is OFF.
        contourEdgeColor
            A String specifying the color to be used to plot the contour edges when
            **contourType** = BANDED or ISOSURFACE. The default value is "Grey60".
        contourEdgeStyle
            A SymbolicConstant specifying the edge line style to be used to plot the contour edges
            when **contourType** = BANDED or ISOSURFACE. Possible values are SOLID, DASHED, DOTTED, and
            DOT_DASH. The default value is SOLID.
        contourEdgeThickness
            A SymbolicConstant specifying the edge line thickness to be used to plot the edge of the
            contour intervals when **contourType** = BANDED or ISOSURFACE. Possible values are
            VERY_THIN, THIN, MEDIUM, and THICK. The default value is VERY_THIN.
        tickmarkAxisLength
            A SymbolicConstant specifying the length of the tick mark plot axes. Possible values are
            SHORT, MEDIUM, and LONG. The default value is MEDIUM.
        tickmarkBaseValue
            A Float specifying the base contour value defining the tick mark axis contour value that
            intersects the elements. Possible values are **autoMinValue** ≤≤ **tickmarkBaseValue** ≤≤
            **autoMaxValue**. The default value is 0.0.
        tickmarkOrientation
            A SymbolicConstant specifying the orientation of the tick mark plots. Possible values
            are N1 and N2. The default value is N2.
        tickmarkCurveColor
            A String specifying the color to be used to plot the tick mark curve. The default value
            is "Cyan".
        averagedOrientationDisplay
            A Boolean specifying the display of the nodal averaged coordinate systems used when
            averaging element vector or tensor data. The default value is OFF.
        extrapolatedAveraging
            A Boolean specifying whether to auto-compute contour limits using extrapolated values
            alone or extrapolated values that are averaged. The default value is OFF.
        showMaxLocation
            A Boolean specifying whether to display location of maximum value. The default value is
            OFF.
        showMinLocation
            A Boolean specifying whether to display location of minimum value. The default value is
            OFF.
        legendHideOutsideLimits
            A Boolean specifying whether to hide the values outside the specified minimum/maximum
            for the contour interval when *legendHideOutsideLimits*=ON. The default value is OFF.

        Raises
        ------
        RangeError
        """
        pass



from abaqusConstants import *
from ..Region.Region import Region


class BoundaryCondition:
    """The BoundaryCondition object is the abstract base type for other BoundaryCondition
    objects. The BoundaryCondition object has no explicit constructor. The methods and
    members of the BoundaryCondition object are common to all objects derived from the
    BoundaryCondition.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].boundaryConditions[name]
    """

    #: A String specifying the boundary condition repository key.
    name: str = ""

    #: A SymbolicConstant specifying the category of the boundary condition. Possible values
    #: are MECHANICAL and THERMAL.
    category: SymbolicConstant = None

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the boundary condition is applied.
    region: Region = Region()

    #: None or a DatumCsys object specifying the local coordinate system of the boundary
    #: condition's degrees of freedom. If **localCsys** = None, the degrees of freedom are defined
    #: in the global coordinate system. The default value is None.
    localCsys: str = None

    def deactivate(self, stepName: str):
        """This method deactivates the boundary condition in the specified step and all subsequent
        steps.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the boundary condition is deactivated.
        """
        pass

    def move(self, fromStepName: str, toStepName: str):
        """This method moves the boundary condition state from one step to a different step.

        Parameters
        ----------
        fromStepName
            A String specifying the name of the step from which the boundary condition state is
            moved.
        toStepName
            A String specifying the name of the step to which the boundary condition state is moved.
        """
        pass

    def reset(self, stepName: str):
        """This method resets the boundary condition state of the specified step to the state of
        the previous analysis step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the boundary condition state is reset.
        """
        pass

    def resume(self):
        """This method resumes the boundary condition that was previously suppressed."""
        pass

    def suppress(self):
        """This method suppresses the boundary condition."""
        pass

    def delete(self, indices: tuple):
        """This method allows you to delete existing boundary conditions.

        Parameters
        ----------
        indices
            A sequence of Ints specifying the index of each boundary condition to delete.
        """
        pass

    def setValues(self, *args, **kwargs):
        pass

    def setValuesInStep(self, *args, **kwargs):
        pass



class OdbDataSection:
    """The OdbDataSection object stores section data.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
            session.odbData[name].sections[i]
    """

    #: A String specifying the set name. This attribute is read-only.
    name: str = ""

    #: A String-to-tuple-of-Ints Dictionary specifying the elements in the set. This attribute
    #: is read-only.
    elements: str = ""



from abaqusConstants import *
from .Area import Area
from .AreaStyle import AreaStyle
from .AxisArray import AxisArray
from .Legend import Legend
from .LineStyle import LineStyle
from .TextStyle import TextStyle
from .XYCurve import XYCurve
from ..UtilityAndView.View import View


class Chart:
    """The Chart object is used to display XYCurve objects. A :py:class:`~abaqus.XY.Chart.Chart` object is automatically
    created when creating an XYPlot object

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
            session.charts[name]
            session.xyPlots[name].charts[name]
    """

    #: A String specifying the name of the Chart object.
    name: str = ""

    #: A Boolean specifying whether to use the QuantityType to associate curves with axes. The
    #: default value is ON.
    useQuantityType: Boolean = ON

    #: A Float specifying the aspect ratio of the grid area. A value of -1 specifies that the
    #: gridArea will take up all available space. The default value is −1.
    aspectRatio: float = None

    #: A repository of XYCurve objects specifying a repository of XYCurve objects to display in
    #: the Chart.
    curves: dict[str, XYCurve] = dict[str, XYCurve]()

    #: An :py:class:`~abaqus.XY.AxisArray.AxisArray` object specifying a read-only sequence of axis objects displayed as axes1 -
    #: the abscissa for a Cartesian chart.
    axes1: AxisArray = AxisArray()

    #: An :py:class:`~abaqus.XY.AxisArray.AxisArray` object specifying a read-only sequence of axis objects displayed as axes2 -
    #: the ordinate for a Cartesian chart.
    axes2: AxisArray = AxisArray()

    #: An :py:class:`~abaqus.XY.Area.Area` object specifying position, padding, background and borders of the chart.
    area: Area = Area()

    #: An :py:class:`~abaqus.XY.Area.Area` object specifying how to display the grid area.
    gridArea: Area = Area()

    #: A :py:class:`~abaqus.XY.Legend.Legend` object specifying the attributes for the legend of the chart.
    legend: Legend = Legend()

    #: A :py:class:`~abaqus.XY.LineStyle.LineStyle` object specifying the line properties to be used when drawing major
    #: gridlines along axis 1.
    majorAxis1GridStyle: LineStyle = LineStyle()

    #: A :py:class:`~abaqus.XY.LineStyle.LineStyle` object specifying the line properties to be used when drawing major
    #: gridlines along axis 2.
    majorAxis2GridStyle: LineStyle = LineStyle()

    #: A :py:class:`~abaqus.XY.LineStyle.LineStyle` object specifying the line properties to be used when drawing minor
    #: gridlines along axis 1.
    minorAxis1GridStyle: LineStyle = LineStyle()

    #: A :py:class:`~abaqus.XY.LineStyle.LineStyle` object specifying the line properties to be used when drawing minor
    #: gridlines along axis 2.
    minorAxis2GridStyle: LineStyle = LineStyle()

    #: A :py:class:`~abaqus.XY.TextStyle.TextStyle` object specifying the text properties to be used when creating tags.
    tagTextStyle: TextStyle = TextStyle()

    #: An :py:class:`~abaqus.XY.AreaStyle.AreaStyle` object specifying the area properties to be used when creating tags.
    tagAreaStyle: AreaStyle = AreaStyle()

    #: A :py:class:`~abaqus.XY.LineStyle.LineStyle` object specifying the tag area border properties to be used when creating
    #: tags.
    tagBorder: LineStyle = LineStyle()

    #: A tuple of Floats specifying a transformation matrix used to scale or pan along the axes
    #: of the Chart.
    transform: float = None

    def autoColor(self, lines: Boolean = OFF, symbols: Boolean = OFF):
        """This method distributes the colors on all curves displayed in the chart using the color
        palette defined by the xyColors object.

        Parameters
        ----------
        lines
            A Boolean defining whether color distribution affects curve lines.
        symbols
            A Boolean defining whether color distribution affects curve symbols.
        """
        pass

    def autoSymbol(self):
        """This method distributes the symbols on all curves displayed in the chart."""
        pass

    def fitCurves(self):
        """This method resets the transform of the chart. It cancels any zoom or pan action."""
        pass

    def getAxis1(self, curve: str, quantityType: str):
        """This method returns the Axis object used for displaying the Axis1 of the XYCurve
        specified by name or object or used for the given QuantityType object.

        Parameters
        ----------
        curve
            The name or the XYCurve object associated to the Axis object.
        quantityType
            The QuantityType object associated to the Axis object.

        Returns
        -------
        Axis
            An :py:class:`~abaqus.XY.Axis.Axis` object.

        Raises
        ------
        XypError: Curve not found
            If the given XYCurve is not used in the Chart.
        TypeError: Specify curve or quantityType; too many arguments; expected 1, got 2
            If both arguments are specified.
        ValueError: QuantityType not found
            If the given QuantityType is not used in the Chart.
        """
        pass

    def getAxis2(self, curve: str, quantityType: str):
        """This method returns the Axis object used for displaying the Axis2 of the XYCurve
        specified by name or object or used for the given QuantityType object.

        Parameters
        ----------
        curve
            The name or the XYCurve object associated to the Axis object.
        quantityType
            The QuantityType object associated to the Axis object.

        Returns
        -------
        Axis
            An :py:class:`~abaqus.XY.Axis.Axis` object.

        Raises
        ------
        XypError: Curve not found
            If the given XYCurve is not used in the Chart.
        TypeError: Specify curve or quantityType; too many arguments; expected 1, got 2
            - If both arguments are specified.
        ValueError: QuantityType not found
            - If the given QuantityType is not used in the Chart.
        """
        pass

    def moveAxisUp(self, axis: str):
        """This method moves the relative position of the given Axis object up in the axis sequence
        of the Chart.

        Parameters
        ----------
        axis
            The Axis object to be moved.
        """
        pass

    def moveAxisDown(self, axis: str):
        """This method moves the relative position of the given Axis object down in the axis
        sequence of the Chart.

        Parameters
        ----------
        axis
            The Axis object to be moved.
        """
        pass

    def removeCurve(self, curve: str):
        """This method removes the given XYCurve from the Chart.

        Parameters
        ----------
        curve
            The XYCurve name or the XYCurve object or a sequence of XYCurve names or XYCurve objects
            to be removed from the Chart.
        """
        pass

    def setValues(
        self,
        chart: "Chart" = None,
        curvesToPlot: tuple[XYCurve] = (),
        aspectRatio: float = None,
        transform: tuple = (),
        view: View = None,
        useQuantityType: Boolean = ON,
    ):
        """This method modifies the Chart object.

        Parameters
        ----------
        chart
            A :py:class:`~abaqus.XY.Chart.Chart` object from which attributes are to be copied.
        curvesToPlot
            A sequence of Strings specifying the names of the curves to plot. In addition to this
            type, the argument can also be one of the following:A String specifying the name of the
            curve to plot.An :py:class:`~abaqus.XY.XYCurve.XYCurve` object specifying the curve to plot.A sequence of XYCurve
            objects specifying the curves to plot (as returned by the curveSet method).
        aspectRatio
            A Float specifying the aspect ratio of the grid area. A value of -1 specifies that the
            gridArea will take up all available space. The default value is −1.
        transform
            A sequence of Floats specifying a transformation matrix used to scale or pan along the
            axes of the Chart.
        view
            A :py:class:`~abaqus.UtilityAndView.View.View` object.
        useQuantityType
            A Boolean specifying whether to use the QuantityType to associate curves with axes. The
            default value is ON.

        Raises
        ------
        RangeError
        """
        pass



from abaqusConstants import *
from .AnalysisStep import AnalysisStep
from ..Adaptivity.AdaptiveMeshConstraintState import AdaptiveMeshConstraintState
from ..Adaptivity.AdaptiveMeshDomain import AdaptiveMeshDomain
from ..BoundaryCondition.BoundaryConditionState import BoundaryConditionState
from ..Load.LoadCase import LoadCase
from ..Load.LoadState import LoadState
from ..PredefinedField.PredefinedFieldState import PredefinedFieldState
from ..StepMiscellaneous.Control import Control
from ..StepMiscellaneous.EmagTimeHarmonicFrequencyArray import (
    EmagTimeHarmonicFrequencyArray,
)
from ..StepMiscellaneous.SolverControl import SolverControl
from ..StepOutput.DiagnosticPrint import DiagnosticPrint
from ..StepOutput.FieldOutputRequestState import FieldOutputRequestState
from ..StepOutput.HistoryOutputRequestState import HistoryOutputRequestState
from ..StepOutput.Monitor import Monitor
from ..StepOutput.Restart import Restart


class EmagTimeHarmonicStep(AnalysisStep):
    """The EmagTimeHarmonicStep object is used to calculate the electromagnetic response of the
    system to harmonic excitation of the model.
    The EmagTimeHarmonicStep object is derived from the AnalysisStep object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import step
            mdb.models[name].steps[name]

        The corresponding analysis keywords are:

        - ELECTROMAGNETIC TIME HARMONIC
                - STEP
    """

    #: A SymbolicConstant specifying the type of matrix storage. Possible values are SYMMETRIC,
    #: UNSYMMETRIC, and SOLVER_DEFAULT. The default value is SOLVER_DEFAULT.
    matrixStorage: SymbolicConstant = SOLVER_DEFAULT

    #: A Boolean specifying whether to subdivide each frequency range using the
    #: eigenfrequencies of the system. The default value is OFF.
    subdivideUsingEigenfrequencies: Boolean = OFF

    #: A SymbolicConstant specifying whether the step has an explicit procedure type
    #: (*procedureType*=ANNEAL, DYNAMIC_EXPLICIT, or DYNAMIC_TEMP_DISPLACEMENT).
    explicit: SymbolicConstant = None

    #: A Boolean specifying whether the step has a perturbation procedure type.
    perturbation: Boolean = OFF

    #: A Boolean specifying whether the step has a mechanical procedure type.
    nonmechanical: Boolean = OFF

    #: A SymbolicConstant specifying the Abaqus procedure. Possible values are:
    #: 
    #: - ANNEAL
    #: - BUCKLE
    #: - COMPLEX_FREQUENCY
    #: - COUPLED_TEMP_DISPLACEMENT
    #: - COUPLED_THERMAL_ELECTRIC
    #: - DIRECT_CYCLIC
    #: - DYNAMIC_IMPLICIT
    #: - DYNAMIC_EXPLICIT
    #: - DYNAMIC_SUBSPACE
    #: - DYNAMIC_TEMP_DISPLACEMENT
    #: - COUPLED_THERMAL_ELECTRICAL_STRUCTURAL
    #: - FREQUENCY
    #: - GEOSTATIC
    #: - HEAT_TRANSFER
    #: - MASS_DIFFUSION
    #: - MODAL_DYNAMICS
    #: - RANDOM_RESPONSE
    #: - RESPONSE_SPECTRUM
    #: - SOILS
    #: - STATIC_GENERAL
    #: - STATIC_LINEAR_PERTURBATION
    #: - STATIC_RIKS
    #: - STEADY_STATE_DIRECT
    #: - STEADY_STATE_MODAL
    #: - STEADY_STATE_SUBSPACE
    #: - VISCO
    procedureType: SymbolicConstant = None

    #: A Boolean specifying whether the step is suppressed or not. The default value is OFF.
    suppressed: Boolean = OFF

    #: A repository of FieldOutputRequestState objects.
    fieldOutputRequestState: dict[str, FieldOutputRequestState] = dict[
        str, FieldOutputRequestState
    ]()

    #: A repository of HistoryOutputRequestState objects.
    historyOutputRequestState: dict[str, HistoryOutputRequestState] = dict[
        str, HistoryOutputRequestState
    ]()

    #: A :py:class:`~abaqus.StepOutput.DiagnosticPrint.DiagnosticPrint` object.
    diagnosticPrint: DiagnosticPrint = DiagnosticPrint()

    #: A :py:class:`~abaqus.StepOutput.Monitor.Monitor` object.
    monitor: Monitor = None

    #: A :py:class:`~abaqus.StepOutput.Restart.Restart` object.
    restart: Restart = Restart()

    #: A repository of AdaptiveMeshConstraintState objects.
    adaptiveMeshConstraintStates: dict[str, AdaptiveMeshConstraintState] = dict[
        str, AdaptiveMeshConstraintState
    ]()

    #: A repository of AdaptiveMeshDomain objects.
    adaptiveMeshDomains: dict[str, AdaptiveMeshDomain] = dict[str, AdaptiveMeshDomain]()

    #: A :py:class:`~abaqus.StepMiscellaneous.Control.Control` object.
    control: Control = Control()

    #: A :py:class:`~abaqus.StepMiscellaneous.SolverControl.SolverControl` object.
    solverControl: SolverControl = SolverControl()

    #: A repository of BoundaryConditionState objects.
    boundaryConditionStates: dict[str, BoundaryConditionState] = dict[
        str, BoundaryConditionState
    ]()

    #: A repository of InteractionState objects.
    interactionStates: int = None

    #: A repository of LoadState objects.
    loadStates: dict[str, LoadState] = dict[str, LoadState]()

    #: A repository of LoadCase objects.
    loadCases: dict[str, LoadCase] = dict[str, LoadCase]()

    #: A repository of PredefinedFieldState objects.
    predefinedFieldStates: dict[str, PredefinedFieldState] = dict[
        str, PredefinedFieldState
    ]()

    #: A String specifying the repository key.
    name: str

    #: A String specifying the name of the previous step. The new step appears after this step
    #: in the list of analysis steps.
    previous: str

    #: An :py:class:`~abaqus.StepMiscellaneous.EmagTimeHarmonicFrequencyArray.EmagTimeHarmonicFrequencyArray` object.
    frequencyRange: EmagTimeHarmonicFrequencyArray

    #: A String specifying a description of the new step. The default value is an empty string.
    description: str = ""

    #: A SymbolicConstant specifying whether damping terms are to be ignored so that a real,
    #: rather than a complex, system matrix is factored. Possible values are REAL_ONLY and
    #: COMPLEX. The default value is COMPLEX.
    factorization: SymbolicConstant = COMPLEX

    def __init__(
        self,
        name: str,
        previous: str,
        frequencyRange: EmagTimeHarmonicFrequencyArray,
        description: str = "",
        factorization: SymbolicConstant = COMPLEX,
    ):
        """This method creates a EmagTimeHarmonicStep object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].EmagTimeHarmonicStep

        Parameters
        ----------
        name
            A String specifying the repository key.
        previous
            A String specifying the name of the previous step. The new step appears after this step
            in the list of analysis steps.
        frequencyRange
            An :py:class:`~abaqus.StepMiscellaneous.EmagTimeHarmonicFrequencyArray.EmagTimeHarmonicFrequencyArray` object.
        description
            A String specifying a description of the new step. The default value is an empty string.
        factorization
            A SymbolicConstant specifying whether damping terms are to be ignored so that a real,
            rather than a complex, system matrix is factored. Possible values are REAL_ONLY and
            COMPLEX. The default value is COMPLEX.

        Returns
        -------
        EmagTimeHarmonicStep
            An :py:class:`~abaqus.Step.EmagTimeHarmonicStep.EmagTimeHarmonicStep` object.

        Raises
        ------
        RangeError
        """
        super().__init__()
        pass

    def setValues(
        self, description: str = "", factorization: SymbolicConstant = COMPLEX
    ):
        """This method modifies the EmagTimeHarmonicStep object.

        Parameters
        ----------
        description
            A String specifying a description of the new step. The default value is an empty string.
        factorization
            A SymbolicConstant specifying whether damping terms are to be ignored so that a real,
            rather than a complex, system matrix is factored. Possible values are REAL_ONLY and
            COMPLEX. The default value is COMPLEX.

        Raises
        ------
        RangeError
        """
        pass



from .Interaction import Interaction


class FluidInflator(Interaction):
    """The FluidInflator object is used to define a fluid inflator to model deployment of an
    airbag.
    The FluidInflator object is derived from the Interaction object.

    .. note::
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].interactions[name]

    The corresponding analysis keywords are:

    - FLUID INFLATOR

    """

    def __init__(
        self,
        name: str,
        createStepName: str,
        cavity: str,
        interactionProperty: str,
        inflationTimeAmplitude: str = "",
        massFlowAmplitude: str = "",
    ):
        """This method creates a FluidInflator object.

        .. note::
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].FluidInflator

        Parameters
        ----------
        name
            A String specifying the repository key.
        createStepName
            A String specifying the name of the step in which the FluidInflator object is created.
        cavity
            A String specifying the first FluidCavity object associated with this interaction.
        interactionProperty
            A String specifying the FluidInflatorProperty object associated with this interaction.
        inflationTimeAmplitude
            A string specifying the name of the amplitude curve defining a mapping between the
            inflation time and the actual time.
        massFlowAmplitude
            A string specifying the name of the amplitude curve by which to modify the mass flow
            rate.

        Returns
        -------
            A FluidInflator object.
        """
        super().__init__()
        pass

    def setValues(self, inflationTimeAmplitude: str = "", massFlowAmplitude: str = ""):
        """This method modifies the FluidInflator object.

        Parameters
        ----------
        inflationTimeAmplitude
            A string specifying the name of the amplitude curve defining a mapping between the
            inflation time and the actual time.
        massFlowAmplitude
            A string specifying the name of the amplitude curve by which to modify the mass flow
            rate.
        """
        pass



from .CommandRegister import CommandRegister


class RegisteredDictionary(CommandRegister):
    """This class allows you to create a dictionary that can be queried from the GUI and is
    capable of notifying the GUI when the contents of the dictionary change. The keys to a
    RegisteredDictionary must be either strings or integers.
    The RegisteredDictionary object is derived from the CommandRegister object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import customKernel
    """

    def __init__(self):
        """This method creates a RegisteredDictionary object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                customKernel.RegisteredDictionary

        Returns
        -------
        RegisteredDictionary
            A :py:class:`~abaqus.CustomKernel.RegisteredDictionary.RegisteredDictionary` object.
        """
        super().__init__()
        pass

    def Methods(self):
        """The RegisteredDictionary object supports the same methods as a Python dictionary. In
        addition, the RegisteredDictionary object supports the changeKey method.
        """
        pass

    def changeKey(self, fromName: str, toName: str):
        """This method changes the name of a key in the dictionary.

        Parameters
        ----------
        fromName
            A String or an integer specifying the name of the key to be changed.
        toName
            A String or an integer specifying the new name for the key.
        """
        pass



from abaqusConstants import *


class LoadDisplayOptions:
    """The LoadDisplayOptions object stores settings that specify how assemblies are to be
    displayed in a particular viewport when
    session.viewports[name].assemblyDisplay.loads=ON
    The LoadDisplayOptions object has no constructor. When you create a new viewport, the
    settings are copied from the current viewport.

    Notes
    -----
    This object can be accessed by:

    .. code-block::

        session.viewports[name].assemblyDisplay.loadOptions
        session.viewports[name].layers[name].assemblyDisplay.loadOptions
    """

    def setValues(
        self,
        concentratedForce: str = ON,
        moment: str = ON,
        pressure: str = ON,
        pipePressure: str = ON,
        bodyForce: str = ON,
        lineLoad: str = ON,
        gravity: str = ON,
        boltLoad: str = ON,
        pegLoad: str = ON,
        connectorForce: str = ON,
        connectorMoment: str = ON,
        inertiaRelief: str = ON,
        rotationalIntertiaLoad: str = ON,
        coriolisForce: str = ON,
        bodyHeatFlux: str = ON,
        surfaceHeatFlux: str = ON,
        concentratedHeatFlux: str = ON,
        concentratedPoreFluid: str = ON,
        surfacePoreFluid: str = ON,
        hydroFluidFlow: str = ON,
        concentratedCharge: str = ON,
        concentratedCurrent: str = ON,
        surfaceCharge: str = ON,
        surfaceCurrent: str = ON,
        bodyCharge: str = ON,
        bodyCurrent: str = ON,
        inwardVolAccel: str = ON,
        bodyConcentrationFlux: str = ON,
        surfaceConcentrationFlux: str = ON,
        concentratedConcentrationFlux: str = ON,
    ):
        """This method modifies the LoadDisplayOptions object.
        concentratedForce
            ​		A Boolean specifying whether concentrated force symbols are shown. The default value
            is ON.
        moment
            ​		A Boolean specifying whether moment symbols are shown. The default value is ON.
        pressure
            ​		A Boolean specifying whether pressure symbols are shown. The default value is ON.
        pipePressure
            ​		A Boolean specifying whether pipe pressure symbols are shown. The default value is
            ON.
        bodyForce
            ​		A Boolean specifying whether body force symbols are shown. The default value is ON.
        lineLoad
            ​		A Boolean specifying whether line load symbols are shown. The default value is ON.
        gravity
            ​		A Boolean specifying whether gravity symbols are shown. The default value is ON.
        boltLoad
            ​		A Boolean specifying whether bolt load symbols are shown. The default value is ON.
        pegLoad
            ​		A Boolean specifying whether PEG load symbols are shown. The default value is ON.
        connectorForce
            ​		A Boolean specifying whether connector force symbols are shown. The default value is
            ON.
        connectorMoment
            ​		A Boolean specifying whether connector moment symbols are shown. The default value is
            ON.
        inertiaRelief
            ​		A Boolean specifying whether inertia relief symbols are shown. The default value is
            ON.
        rotationalIntertiaLoad
            ​		A Boolean specifying whether rotational inertia load symbols are shown. The default
            value is ON.
        coriolisForce
            ​		A Boolean specifying whether coriolis force symbols are shown. The default value is
            ON.
        bodyHeatFlux
            ​		A Boolean specifying whether body heat flux symbols are shown. The default value is
            ON.
        surfaceHeatFlux
            ​		A Boolean specifying whether surface heat flux symbols are shown. The default value
            is ON.
        concentratedHeatFlux
            ​		A Boolean specifying whether concentrated heat flux symbols are shown. The default
            value is ON.
        concentratedPoreFluid
            ​		A Boolean specifying whether concentrated pore fluid symbols are shown. The default
            value is ON.
        surfacePoreFluid
            ​		A Boolean specifying whether surface pore fluid symbols are shown. The default value
            is ON.
        hydroFluidFlow
            ​		A Boolean specifying whether hydro fluid flow symbols are shown. The default value is
            ON.
        concentratedCharge
            ​		A Boolean specifying whether concentrated charge symbols are shown. The default value
            is ON.
        concentratedCurrent
            ​		A Boolean specifying whether concentrated current symbols are shown. The default
            value is ON.
        surfaceCharge
            ​		A Boolean specifying whether surface charge symbols are shown. The default value is
            ON.
        surfaceCurrent
            ​		A Boolean specifying whether surface current symbols are shown. The default value is
            ON.
        bodyCharge
            ​		A Boolean specifying whether body charge symbols are shown. The default value is ON.
        bodyCurrent
            ​		A Boolean specifying whether body current symbols are shown. The default value is ON.
        inwardVolAccel
            ​		A Boolean specifying whether inward volume acceleration symbols are shown. The
            default value is ON.
        bodyConcentrationFlux
            ​		A Boolean specifying whether body concentration flux symbols are shown. The default
            value is ON.
        surfaceConcentrationFlux
            ​		A Boolean specifying whether surface concentration flux symbols are shown. The
            default value is ON.
        concentratedConcentrationFlux
            ​	A Boolean specifying whether concentrated concentration flux symbols are shown. The
            default value is ON.

        Raises
        ------
        RangeError
        """
        pass



from abaqusConstants import *


class AVIOptions:
    """The AVIOptions object is used to store values and attributes to be used in generating
    AVI animation. The AVIOptions object has no constructor. Abaqus creates the **aviOptions**
    member when the animation module is imported.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import animation
            session.aviOptions
    """

    def setValues(
        self,
        compressionMethod: SymbolicConstant = RLE8,
        compressionQuality: int = None,
        codecOptions: str = "",
        sizeDefinition: SymbolicConstant = SIZE_ON_SCREEN,
        imageSize: int = None,
    ):
        """This method modifies the AVIOptions object.

        Parameters
        ----------
        compressionMethod
            A SymbolicConstant specifying the compression method for the AVI format. Possible values
            are:
            - RAW8, specifying an uncompressed format of 8 bits per pixel.
            - RAW32, specifying an uncompressed format of 32 bits per pixel.
            - RLE8, specifying a run length encoded format of 8 bits per pixel.
            - CODEC, specifying a format defined by CODEC (encoder/decoder). The availability of
              theCODEC is system dependent
              
            The default value is RLE8.
        compressionQuality
            An Int specifying the quality of the compression as a percentage when the
            **compressionMethod** is set to CODEC.
        codecOptions
            A String specifying the system specific options defining the CODEC when the
            **compressionMethod** is set to CODEC.
        sizeDefinition
            A SymbolicConstant specifying how the width and height of the image are specified.
            Possible values are SIZE_ON_SCREEN and USER_DEFINED. The default value is
            SIZE_ON_SCREEN.
        imageSize
            A pair of Ints specifying the width and height of the image in pixels when
            **sizeDefinition** = USER_DEFINED. Possible values are Ints in the range (*minWidth*,
            **minHeight**) ≤≤ (width, height) ≤≤ (*maxWidth*, **maxHeight**). The default value is the
            screen size.
            Note:The values of the minimum width (*minWidth*) and height (*minHeight*) depend on the
            following:viewport font size,whether decorations are printed,decoration size, andscreen
            resolution.The minimum width and height are normally < 50 pixels. The values of the
            maximum width (*maxWidth*) and height (*maxHeight*) depend on the graphics capabilities
            of the system. The maximum width and height will be at least as large as the screen
            dimensions.
        """
        pass
